@@ -28,7 +28,7 @@ local assert, io, type, dofile, loadfile, pcall, tonumber, print, setmetatable
 
 -- Increment each time a savegame break would occur
 -- and add compatibility code in afterLoad functions
-local SAVEGAME_VERSION = 53
+local SAVEGAME_VERSION = 66
 
 class "App"
 
@@ -49,6 +49,7 @@ function App:App()
     motion = self.onMouseMove,
     active = self.onWindowActive,
     music_over = self.onMusicOver,
+    movie_over = self.onMovieOver
   }
   self.strings = {}
   self.savegame_version = SAVEGAME_VERSION
@@ -67,6 +68,18 @@ end
 function App:init()
   -- App initialisation 1st goal: Get the loading screen up
   
+  print("")
+  print("")
+  print("---------------------------------------------------------------")
+  print("")
+  print("Welcome to CorsixTH " .. self:getVersion() .. "!")
+  print("")
+  print("---------------------------------------------------------------")
+  print("")
+  print("This window will display useful information if an error occurs.")
+  print("")
+  print("---------------------------------------------------------------")
+  print("")
   -- Prereq 1: Config file (for screen width / height / TH folder)
   -- Note: These errors cannot be translated, as the config file specifies the language
   local conf_path = self.command_line["config-file"] or "config.txt"
@@ -96,6 +109,18 @@ function App:init()
   if self.savegame_dir:sub(-1, -1) ~= pathsep then
     self.savegame_dir = self.savegame_dir .. pathsep
   end
+  self.screenshot_dir = self.config.screenshots or conf_path:match("^(.-)[^".. pathsep .. "]*$") .. "Screenshots"
+  if self.screenshot_dir:sub(-1, -1) == pathsep then
+    self.screenshot_dir = self.screenshot_dir:sub(1, -2)
+  end
+  if lfs.attributes(self.screenshot_dir, "mode") ~= "directory" then
+    if not lfs.mkdir(self.screenshot_dir) then
+       print "Notice: Savegame directory does not exist and could not be created."
+    end
+  end
+  if self.screenshot_dir:sub(-1, -1) ~= pathsep then
+    self.screenshot_dir = self.screenshot_dir .. pathsep
+  end
   
   -- Create the window
   if not SDL.init("audio", "video", "timer") then
@@ -123,6 +148,9 @@ function App:init()
   self.caption = "CorsixTH (" .. table.concat(caption_descs, ", ") .. ")"
   SDL.wm.setCaption(self.caption)
   local modes = {"hardware", "doublebuf"}
+  if compile_opts.renderer == "OpenGL" then
+    modes[#modes + 1] = "opengl"
+  end
   self.fullscreen = false
   if _MAP_EDITOR then
     MapEditorInitWithLuaApp(self)
@@ -138,6 +166,7 @@ function App:init()
   end
   self.modes = modes
   self.video = assert(TH.surface(self.config.width, self.config.height, unpack(modes)))
+  self.video:setBlueFilterActive(false)
   SDL.wm.setIconWin32()
   
   
@@ -190,6 +219,13 @@ function App:init()
   self.audio = Audio(self)
   self.audio:init()
   
+  -- Load movie player
+  dofile "movie_player"
+  self.moviePlayer = MoviePlayer(self, self.audio)
+  if good_install_folder then
+    self.moviePlayer:init()
+  end
+
   -- Load strings before UI and before additional Lua
   dofile "strings"
   dofile "string_extensions"
@@ -252,6 +288,9 @@ function App:init()
     self:loadLevel("")
   else
     self:loadMainMenu()
+    if self.config.play_intro then
+      self.moviePlayer:playIntro()
+    end
     -- If we couldn't properly load the language, show an information dialog
     if not language_load_success then
       -- At this point we know the language is english, so no use having
@@ -324,6 +363,9 @@ function App:initLanguage()
 end
 
 function App:loadMainMenu(message)
+  -- Make sure there is no blue filter active.
+  self.video:setBlueFilterActive(false)
+
   -- Unload ui, world and map
   self.ui = nil
   self.world = nil
@@ -357,13 +399,16 @@ function App:loadLevel(level, ...)
       world = {room_built = self.world.room_built},
       hospital = {
         player_salary = self.ui.hospital.player_salary,
-        research_dep_built = self.ui.hospital.research_dep_built,
         message_popup = self.ui.hospital.message_popup,
         hospital_littered = self.ui.hospital.hospital_littered,
+        has_seen_pay_rise = self.ui.hospital.has_seen_pay_rise,
       },
     }
   end
   
+  -- Make sure there is no blue filter active.
+  self.video:setBlueFilterActive(false)
+
   -- Unload ui, world and map
   self.ui = nil
   self.world = nil
@@ -381,7 +426,11 @@ function App:loadLevel(level, ...)
   -- Load UI
   self.ui = GameUI(self, self.world:getLocalPlayerHospital())
   self.world:setUI(self.ui) -- Function call allows world to set up its keyHandlers
-  
+ 
+  if tonumber(level) then
+    self.moviePlayer:playAdvanceMovie(level)
+  end
+ 
   -- Now restore progress from previous levels.
   if carry_to_next_level then
     self.world:initFromPreviousLevel(carry_to_next_level)
@@ -465,9 +514,14 @@ function App:dumpStrings()
   -- for _, lang in ipairs(self.strings.languages_english) do
   --   self:checkMissingStringsInLanguage(dir, lang)
   -- end
+  print("")
+  print("------------------------------------------------------")
+  print("Dumped strings to default configuration file directory")
+  print("------------------------------------------------------")
+  print("")
 end
 
---!Compares strings provided by language file of given language WITHOUT inheritance
+--! Compares strings provided by language file of given language WITHOUT inheritance
 -- with strings provided by english language with inheritance (i.e. all strings).
 -- This will give translators an idea which strings are missing in their translation.
 --!param dir The directory where the file to write to should be.
@@ -730,10 +784,12 @@ function App:dispatch(evt_type, ...)
 end
 
 function App:onTick(...)
-  if self.world then
-    self.world:onTick(...)
+  if(not self.moviePlayer.playing) then
+    if self.world then
+      self.world:onTick(...)
+    end
+    self.ui:onTick(...)
   end
-  self.ui:onTick(...)
   return true -- tick events always result in a repaint
 end
 
@@ -743,9 +799,13 @@ local fps_sum = 0 -- Sum of fps_history array
 local fps_next = 1 -- Used to loop through fps_history when [over]writing
 
 function App:drawFrame()
-  self.video:startFrame()
-  self.ui:draw(self.video)
-  self.video:endFrame()
+  if(self.moviePlayer.playing) then
+    self.moviePlayer:refresh()
+  else
+    self.video:startFrame()
+    self.ui:draw(self.video)
+    self.video:endFrame()
+  end
   
   if self.config.track_fps then
     fps_sum = fps_sum - fps_history[fps_next]
@@ -789,6 +849,10 @@ function App:onMusicOver(...)
   return self.audio:onMusicOver(...)
 end
 
+function App:onMovieOver(...)
+  self.moviePlayer:onMovieOver(...)
+end
+
 function App:checkInstallFolder()
   self.fs = FileSystem()
   local status, err
@@ -817,9 +881,11 @@ function App:checkInstallFolder()
   check("QData".. pathsep .."SPointer.dat")
   if #missing ~= 0 then
     missing = table.concat(missing, ", ")
-    error("Invalid Theme Hospital install folder specified in config file, "..
+    print("Invalid Theme Hospital install folder specified in config file, "..
           "as at least the following files are missing: ".. missing ..".\n"..
           message)
+    print("Trying to let the user select a new one.")
+    return false
   end
     
   -- Check for demo version
@@ -967,8 +1033,12 @@ end
 -- a specific savegame verion is from.
 function App:getVersion(version)
   local ver = version or self.savegame_version
-  if ver > 53 then
+  if ver > 66 then
     return "Trunk"
+  elseif ver > 54 then
+    return "0.20"
+  elseif ver > 53 then
+    return "0.11"
   elseif ver > 51 then
     return "0.10"
   elseif ver > 45 then
@@ -1012,13 +1082,6 @@ function App:restart()
   end))
 end
 
---! Quits the running game and returns to main menu (offers confirmation window first)
-function App:quit()
-  self.ui:addWindow(UIConfirmDialog(self.ui, _S.confirmation.quit, --[[persistable:app_confirm_quit]] function()
-    self:loadMainMenu()
-  end))
-end
-
 --! Exits the game completely (no confirmation window)
 function App:exit()
   -- Save config before exiting
@@ -1036,13 +1099,19 @@ function App:afterLoad()
     self.world.game_log = {}
     self.world:gameLog("Created Gamelog on load of old (pre-versioning) savegame.")
   end
-  
+  if not self.world.original_savegame_version then
+    self.world.original_savegame_version = old
+  end
+  local first = self.world.original_savegame_version
   if new == old then
-    self.world:gameLog("Savegame version is " .. new .. " (" .. self:getVersion() .. ")")
+    self.world:gameLog("Savegame version is " .. new .. " (" .. self:getVersion() 
+      .. "), originally it was " .. first .. " (" .. self:getVersion(first) .. ")")
     return
   elseif new > old then
     self.world:gameLog("Savegame version changed from " .. old .. " (" .. self:getVersion(old) ..
-                       ") to " .. new .. " (" .. self:getVersion() .. ").")
+                       ") to " .. new .. " (" .. self:getVersion() .. 
+                       "). The save was created using " .. first .. 
+                       " (" .. self:getVersion(first) .. ")")
   else
     -- TODO: This should maybe be forbidden completely.
     self.world:gameLog("Warning: loaded savegame version " .. old .. " (" .. self:getVersion(old) ..
@@ -1054,3 +1123,8 @@ function App:afterLoad()
   self.world:afterLoad(old, new)
   self.ui:afterLoad(old, new)
 end
+
+
+-- Do not remove, for savegame compatibility < r1891
+local app_confirm_quit_stub = --[[persistable:app_confirm_quit]] function()
+end
