@@ -319,13 +319,6 @@ function UIMenuBar:disappear()
   end
 end
 
-function UIMenuBar:onKeyDown(key)
-  if key == "esc" then
-    self:appear()
-    return true
-  end
-end
-
 function UIMenuBar:onMouseDown(button, x, y)
   if button ~= "left" or not self.visible then
     return
@@ -517,7 +510,7 @@ function UIMenuBar:makeMenu(app)
   menu:appendItem(_S.menu_file.load, function() self.ui:addWindow(UILoadGame(self.ui, "game")) end)
     :appendItem(_S.menu_file.save, function() self.ui:addWindow(UISaveGame(self.ui)) end)
     :appendItem(_S.menu_file.restart, function() app:restart() end)
-    :appendItem(_S.menu_file.quit, function() app:quit() end)
+    :appendItem(_S.menu_file.quit, function() self.ui:quit() end)
   self:addMenu(_S.menu.file, menu)
   
   local options = UIMenu()
@@ -527,34 +520,43 @@ function UIMenuBar:makeMenu(app)
         return level == app.config.music_volume,
           function()
             app.audio:setBackgroundVolume(level)
+            app:saveConfig()
           end,
           ""
       elseif setting == "sound" then
         return level == app.config.sound_volume,
           function()
             app.audio:setSoundVolume(level)
+            app:saveConfig()
           end,
           ""
       else
         return level == app.config.announcement_volume,
           function()
             app.audio:setAnnouncementVolume(level)
+            app:saveConfig()
           end,
           ""
       end
     end
     local function playSounds(item)
       app.audio:playSoundEffects(item.checked)
+      app:saveConfig()
     end
     local function playAnno(item)
       app.config.play_announcements = item.checked
+      app:saveConfig()
     end
     local function playMusic(item)
       if not app.audio.background_music then
+        app.config.play_music = true
         app.audio:playRandomBackgroundTrack() -- play
       else
-        app.audio:pauseBackgroundTrack() -- pause or unpause
+        app.config.play_music = false
+        app.audio:stopBackgroundTrack() -- stop
       end
+      -- Also save this directly to the configuration file.
+      app:saveConfig()
     end
     local function musicStatus(item)
       return not not app.audio.background_music and not app.audio.background_paused
@@ -583,14 +585,32 @@ function UIMenuBar:makeMenu(app)
   end
   options:appendCheckItem(_S.menu_options.lock_windows, boolean_runtime_config"lock_windows")
   options:appendCheckItem(_S.menu_options.edge_scrolling,
-    not self.ui.app.config.prevent_edge_scrolling,
-    function(item) self.ui.app.config.prevent_edge_scrolling = not item.checked end,
+    not app.config.prevent_edge_scrolling,
+    function(item) app.config.prevent_edge_scrolling = not item.checked end,
     nil,
-    function() return not self.ui.app.config.prevent_edge_scrolling end)
+    function() return not app.config.prevent_edge_scrolling end)
   options:appendCheckItem(_S.menu_options.adviser_disabled, 
-    not self.ui.app.config.adviser_disabled,
-    function(item) self.ui.app.config.adviser_disabled = not item.checked end)
-    
+    not app.config.adviser_disabled,
+    function(item) 
+      app.config.adviser_disabled = not item.checked
+      app:saveConfig() 
+    end)
+  
+  local function temperatureDisplay(method)
+    --local map = app.world.map
+    return method == 1, function()
+      app.world.map:setTemperatureDisplayMethod(method)
+    end, "", function () 
+      return app.world.map.temperature_display_method == method
+    end      
+  end
+  
+  options:appendMenu(_S.menu_options.warmth_colors, UIMenu()
+    :appendCheckItem(_S.menu_options_warmth_colors.choice_1, temperatureDisplay(1))
+    :appendCheckItem(_S.menu_options_warmth_colors.choice_2, temperatureDisplay(2))
+    :appendCheckItem(_S.menu_options_warmth_colors.choice_3, temperatureDisplay(3))
+  )
+  
   local function rate(speed)
     return speed == "Normal", function()
       app.world:setSpeed(speed)
@@ -610,19 +630,20 @@ function UIMenuBar:makeMenu(app)
   options:appendItem(_S.menu_options.settings, function() self.ui:addWindow(UIOptions(self.ui, "game")) end)
   self:addMenu(_S.menu.options, options)
   self:addMenu(_S.menu.charts, UIMenu()
-    :appendItem(_S.menu_charts.statement, function() self.ui.bottom_panel:dialogBankStats() end)
-    :appendItem(_S.menu_charts.casebook, function() self.ui.bottom_panel:dialogDrugCasebook() end)
-    :appendItem(_S.menu_charts.policy, function() self.ui.bottom_panel:dialogPolicy() end)
-    :appendItem(_S.menu_charts.research)
-    :appendItem(_S.menu_charts.graphs)
-    :appendItem(_S.menu_charts.staff_listing, function() self.ui.bottom_panel:dialogStaffManagement() end)
-    :appendItem(_S.menu_charts.bank_manager, function() self.ui.bottom_panel:dialogBankManager() end)
-    :appendItem(_S.menu_charts.status, function() self.ui.bottom_panel:dialogStatus() end)
+    :appendItem(_S.menu_charts.bank_manager, function() self.ui.bottom_panel:dialogBankManager(true) end)
+    :appendItem(_S.menu_charts.statement, function() self.ui.bottom_panel:dialogBankStats(true) end)
+    :appendItem(_S.menu_charts.staff_listing, function() self.ui.bottom_panel:dialogStaffManagement(true) end)
+    :appendItem(_S.menu_charts.town_map, function() self.ui.bottom_panel:dialogTownMap(true) end)
+    :appendItem(_S.menu_charts.casebook, function() self.ui.bottom_panel:dialogDrugCasebook(true) end)
+    :appendItem(_S.menu_charts.research, function() self.ui.bottom_panel:dialogResearch(true) end)
+    :appendItem(_S.menu_charts.status, function() self.ui.bottom_panel:dialogStatus(true) end)
+    :appendItem(_S.menu_charts.graphs, function() self.ui.bottom_panel:dialogCharts(true) end)
+    :appendItem(_S.menu_charts.policy, function() self.ui.bottom_panel:dialogPolicy(true) end)
     :appendItem(_S.menu_charts.briefing, function() self.ui:showBriefing() end)
   )
   local function _(s) return "  " .. s:upper() .. "  " end
   local function transparent_walls(item)
-    app.ui:makeWallsTransparent(item.checked)
+    app.ui:toggleWallsTransparent()
   end
   local function limit_camera(item)
     app.ui:limitCamera(item.checked)
