@@ -85,6 +85,7 @@ end
  
 function Patient:setDiagnosed(diagnosed)
   self.diagnosed = diagnosed
+  self.treatment_history[#self.treatment_history + 1] = self.disease.name
   local window = self.world.ui:getWindow(UIPatient)
   if window and window.patient == self then
     window:updateInformation()
@@ -158,7 +159,8 @@ function Patient:treated() -- If a drug was used we also need to pay for this
   local amount = self.hospital.disease_casebook[self.disease.id].drug_cost or 0
   hospital:receiveMoneyForTreatment(self)
   if amount ~= 0 then
-    hospital:spendMoney(amount, _S.transactions.drug_cost)
+  local str = _S.drug_companies[math.random(1 , 5)]
+  hospital:spendMoney(amount, _S.transactions.drug_cost .. ": " .. str)
   end
 
   -- Either the patient is no longer sick, or he/she dies.
@@ -183,7 +185,7 @@ function Patient:treated() -- If a drug was used we also need to pay for this
         self.hospital.emergency.cured_emergency_patients = hospital.emergency.cured_emergency_patients + 1
       end
       self:setMood("cured", "activate")
-      self:playSound "cheer.wav"
+      self.world.ui:playSound "cheer.wav" -- This sound is always heard
       self.attributes["health"] = 1
       self:changeAttribute("happiness", 0.8)
       hospital:changeReputation("cured", self.disease)
@@ -208,16 +210,20 @@ function Patient:treated() -- If a drug was used we also need to pay for this
 end
 
 function Patient:die()
-  if self.hospital.num_deaths < 1 then
+  -- It may happen that this patient was just cured and then the room blew up.
+  -- (Hospital not set when going home)
+  local hospital = self.hospital or self.world:getLocalPlayerHospital()
+  
+  if hospital.num_deaths < 1 then
     self.world.ui.adviser:say(_A.information.first_death)
   end
-  self.hospital:humanoidDeath(self)
+  hospital:humanoidDeath(self)
   if not self.is_debug then
-    local casebook = self.hospital.disease_casebook[self.disease.id]
+    local casebook = hospital.disease_casebook[self.disease.id]
     casebook.fatalities = casebook.fatalities + 1
   end
   self:setMood("dead", "activate")
-  self:playSound "boo.wav"
+  self.world.ui:playSound "boo.wav" -- this sound is always heard
   self.going_home = true
   if self:getRoom() then
     self:queueAction{name = "meander", count = 1}
@@ -225,7 +231,7 @@ function Patient:die()
     self:setNextAction{name = "meander", count = 1}
   end  
   if self.is_emergency then
-    self.hospital.emergency.killed_emergency_patients = self.hospital.emergency.killed_emergency_patients + 1
+    hospital.emergency.killed_emergency_patients = hospital.emergency.killed_emergency_patients + 1
   end
   self:queueAction{name = "die"}
   self:updateDynamicInfo(_S.dynamic_info.patient.actions.dying)
@@ -413,10 +419,11 @@ function Patient:tapFoot()
 end
 
 function Patient:goHome(cured)
-  if self.going_home then
-    return
-  end
   local hosp = self.hospital
+  if not hosp and self.going_home then
+    -- The patient should be going home already, not much we can do.
+    TheApp.world:gameLog("Warning: goHome called when the patient is already going home")
+  end
   if not cured then
     self:setMood("exit", "activate")
     if not self.is_debug then
@@ -628,11 +635,10 @@ function Patient:tickDay()
             callback = --[[persistable:patient_toilet_build_callback]] function(room)
               if room.room_info.id == "toilets" then
                 self.going_to_toilet = false
-                self.world:unregisterRoomBuildCallback(callback)
+                self:unregisterRoomBuildCallback(callback)
               end
             end
-            self.toilet_callback = callback
-            self.world:registerRoomBuildCallback(callback)
+            self:registerRoomBuildCallback(callback)
           -- Otherwise we can queue the action, but only if not in any rooms right now.
           elseif not self:getRoom() and not self.action_queue[1].is_leaving then
             self:setNextAction{
@@ -864,3 +870,42 @@ function Patient:updateDynamicInfo(action_string)
   end
   self:setDynamicInfo('text', {action_string, "", info})
 end
+
+--[[ Update availability of a choice in message owned by this patient, if any
+!param choice (string) The choice that needs updating (currently "research" or "guess_cure").
+]]
+function Patient:updateMessage(choice)
+  if self.message and self.message.choices then
+    local enabled = false
+    if choice == "research" then
+      -- enable only if research department is built and a room in the treatment chain is undiscovered
+      if self.hospital:hasRoomOfType("research") then
+        local req = self.hospital:checkDiseaseRequirements(self.disease.id)
+        if req then
+          for _, room_id in ipairs(req.rooms) do
+            local room = self.world.available_rooms[room_id]
+            if room and self.hospital.undiscovered_rooms[room] then
+              enabled = true
+              break
+            end
+          end
+        end
+      end
+    else -- if choice == "guess_cure" then
+      -- TODO: implement
+    end
+    
+    for _, c in ipairs(self.message.choices) do
+      if c.choice == choice then
+        c.enabled = enabled
+      end
+    end
+    
+    -- Update the fax window if it is open.
+    local window = self.world.ui:getWindow(UIFax)
+    if window then
+      window:updateChoices()
+    end
+    
+  end
+end
