@@ -32,10 +32,9 @@ function Staff:tickDay()
   Humanoid.tickDay(self)
   -- Pay too low  --> unhappy
   -- Pay too high -->   happy
-  local fair_wage = self.profile:getFairWage(self.world)
+  local fair_wage = self.profile:getFairWage()
   local wage = self.profile.wage
   self:changeAttribute("happiness", 0.05 * (wage - fair_wage) / (fair_wage ~= 0 and fair_wage or 1))
-
   -- if you overwork your Dr's then there is a chance that they can go crazy
   -- when this happens, find him and get him to rest straight away
   if self.attributes["fatigue"] then
@@ -144,8 +143,8 @@ end
 
 function Staff:tick()
   Entity.tick(self)
-  -- don't do anything if they're fired or have no hospital
-  if self.fired or not self.hospital then
+  -- don't do anything if they're fired or picked up or have no hospital
+  if self.fired or self.pickup or not self.hospital then
     return
   end
 
@@ -423,6 +422,7 @@ function Staff:dump()
           "Watering: " .. self.attributes["watering"], 
           "Repairing: " .. self.attributes["repairing"])
   end
+
   Humanoid.dump(self)
 end
 
@@ -551,11 +551,10 @@ function Staff:checkIfNeedRest()
         callback = --[[persistable:staff_build_staff_room_callback]] function(room)
           if room.room_info.id == "staff_room" then
             self.waiting_for_staffroom = nil
-            self.world:unregisterRoomBuildCallback(callback)
-            self.build_callback = nil
+            self:unregisterRoomBuildCallback(callback)
           end
         end
-        self:registerNewRoomBuildCallback(callback)
+        self:registerRoomBuildCallback(callback)
         return
       end
       local room = self:getRoom()
@@ -622,15 +621,7 @@ function Staff:onPlaceInCorridor()
   if self.humanoid_class == "Receptionist" then
     world:findObjectNear(self, "reception_desk", nil, function(x, y)
       local obj = world:getObject(x, y, "reception_desk")
-      if not obj.receptionist and not obj.reserved_for then
-        obj.reserved_for = self
-        self.associated_desk = obj
-        obj.receptionist = self
-        local use_x, use_y = obj:getSecondaryUsageTile()
-        self:setNextAction{name = "walk", x = use_x, y = use_y, must_happen = true}
-        self:queueAction{name = "staff_reception", object = obj, must_happen = true}
-        return true
-      end
+      return obj and obj:occupy(self)
     end)
   end
 end
@@ -649,28 +640,28 @@ local profile_attributes = {
   Researcher = "is_researcher",
 }
 
--- Helper function to decide if Staff fulfills a criterium 
+-- Helper function to decide if Staff fulfills a criterion
 -- (one of "Doctor", "Nurse", "Psychiatrist", "Surgeon", "Researcher" and "Handyman")
-function Staff:fulfillsCriterium(criterium)
+function Staff:fulfillsCriterion(criterion)
   local class = self.humanoid_class
-  if criterium == "Doctor" then
+  if criterion == "Doctor" then
     if class == "Doctor" or class == "Surgeon" then
       return true
     end
-  elseif criterium == "Nurse" then
+  elseif criterion == "Nurse" then
     if class == "Nurse" then
       return true
     end
-  elseif criterium == "Psychiatrist" or criterium == "Surgeon" or criterium == "Researcher" then
-    if self.profile and self.profile[profile_attributes[criterium]] == 1.0 then
+  elseif criterion == "Psychiatrist" or criterion == "Surgeon" or criterion == "Researcher" then
+    if self.profile and self.profile[profile_attributes[criterion]] == 1.0 then
       return true
     end
-  elseif criterium == "Handyman" then
+  elseif criterion == "Handyman" then
     if class == "Handyman" then
       return true
     end
   else
-    error("Unknown criterium " .. criterium)
+    error("Unknown criterion " .. criterion)
   end
   return false
 end
@@ -711,6 +702,9 @@ function Staff:isIdle()
     return false
   end
 
+  if self.waiting_on_other_staff then
+    return false
+  end
   -- if they are using a door they are not idle, this stops doctors being considered for staff selection
   -- for rooms they have not completely left yet, fixes issue 810
   if self.user_of and self.user_of.object_type.id == "door" then
@@ -764,9 +758,15 @@ end
 
 -- Makes the staff member request a raise of 10%, or a wage exactly inbetween their current and a fair one, whichever is more.
 function Staff:requestRaise()
+  -- Is this the first time a member of staff is requesting a raise?
+  -- Only show the help if the player is playing the campaign though
+  if self.hospital and not self.hospital.has_seen_pay_rise and tonumber(self.world.map.level_number) then
+    self.world.ui.adviser:say(_A.information.pay_rise)
+    self.hospital.has_seen_pay_rise = true
+  end
   -- Check whether there is already a request for raise.
   if not self:isMoodActive("pay_rise") then
-    local amount = math.floor(math.max(self.profile.wage * 1.1, (self.profile:getFairWage(self.world) + self.profile.wage) / 2) - self.profile.wage)
+    local amount = math.floor(math.max(self.profile.wage * 1.1, (self.profile:getFairWage() + self.profile.wage) / 2) - self.profile.wage)
     -- At least for now, staff are timid, and only ask for raises 1/5th of the time
     if math.random(1, 5) ~= 1 or amount <= 0 then
       self.timer_until_raise = nil
@@ -837,6 +837,13 @@ function Staff:afterLoad(old, new)
       self.staffroom_needed = nil
     end
   end
+  
+  if old < 64 then
+    -- added reference to world for staff profiles
+    self.profile.world = self.world
+  end
+  
+  Humanoid.afterLoad(self, old, new)
 end
 
 function Staff:intreruptHandymanTask()
@@ -884,13 +891,18 @@ function Staff:searchForHandymanTask()
     end
   end
   if assignedTask == false then
+    -- Make sure that the handyman isn't meandering already.
+    for i, action in ipairs(self.action_queue) do
+      if action.name == "meander" then
+        return false
+      end
+    end
     if self:getRoom() then
       self:queueAction(self:getRoom():createLeaveAction())
     end
     self:queueAction({name = "meander"})
-    return false
   end
-  return true
+  return assignedTask
 end
 
 function Staff:assignHandymanTask(taskIndex, taskType)
@@ -913,3 +925,15 @@ function Staff:assignHandymanTask(taskIndex, taskType)
     task.call.dispatcher:executeCall(task.call, self)
   end
 end
+
+function Staff:getDrawingLayer()
+  if self.humanoid_class == "Receptionist" then
+    local direction = self.last_move_direction
+    if direction == "west" or direction == "north" then
+      return 5
+    end
+    return 3
+  else
+    return 4
+  end
+end
