@@ -68,6 +68,21 @@ function GameUI:GameUI(app, local_hospital)
   self.ticks_since_last_announcement = 0
 end
 
+function GameUI:setupGlobalKeyHandlers()
+  UI.setupGlobalKeyHandlers(self)
+
+  self:addKeyHandler("esc", self, self.setEditRoom, false)
+  self:addKeyHandler("esc", self, self.showMenuBar)
+
+  self:addKeyHandler({"ctrl", "d"}, self.app.world, self.app.world.dumpGameLog)
+  self:addKeyHandler({"ctrl", "t"}, self.app, self.app.dumpStrings)
+
+  if self.app.config.debug then
+    self:addKeyHandler("f11", self, self.showCheatsWindow)
+    self:addKeyHandler("x", self, self.toggleWallsTransparent)
+  end
+end
+
 function GameUI:makeVisibleDiamond(scr_w, scr_h)
   local map_w = self.app.map.width
   local map_h = self.app.map.height
@@ -199,39 +214,15 @@ end
 
 function GameUI:onKeyDown(code, rawchar)
   if UI.onKeyDown(self, code, rawchar) then
+    -- Key has been handled already
     return true
   end
   rawchar = self.key_code_to_rawchar[code] -- UI may have translated rawchar
   local key = self:_translateKeyCode(code, rawchar)
-  
-  --Maybe the player wants to abort an "about to edit room" action
-  if key == "esc" and self.edit_room then
-    self:setEditRoom(false)
-    return true
-  end
-  self.menu_bar:onKeyDown(key, rawchar, code)
   if scroll_keys[key] then
     self:updateKeyScroll()
     return
   end
-  -- Allow players to dump strings to be able to see which strings their language
-  -- is lacking.
-  if key == "d" and self.buttons_down.ctrl and self.buttons_down.shift then
-    self.app:dumpStrings()
-  end
-  if TheApp.config.debug then -- Debug commands
-    if key == "f8" then -- Make debug fax
-      self:makeDebugFax()
-    elseif key == "f9" then -- Make debug patient
-      self:addWindow(UIMakeDebugPatient(self))
-    elseif key == "f11" then -- Open cheat window
-      self:addWindow(UICheats(self))
-    elseif key == "x" then -- Toggle wall transparency
-      self:makeWallsTransparent(not self.transparent_walls)
-    elseif key == "d" and self.buttons_down.ctrl then
-      self.app.world:dumpGameLog()
-    end
-  end
 end
 
 function GameUI:onKeyUp(code)
@@ -308,8 +299,11 @@ function GameUI:onCursorWorldPositionChange()
 
     self.cursor_entity = entity
     if self.cursor ~= self.edit_room_cursor and self.cursor ~= self.waiting_cursor then
-      local cursor = entity and entity.hover_cursor or
+      local cursor = self.default_cursor
+      if self.app.world.user_actions_allowed then
+        cursor = entity and entity.hover_cursor or
         (self.down_count ~= 0 and self.down_cursor or self.default_cursor)
+      end
       self:setCursor(cursor)
     end
     if self.bottom_panel then
@@ -378,6 +372,9 @@ end
 -- TODO: try to remove duplication with UI:onMouseMove
 function GameUI:onMouseMove(x, y, dx, dy)
   local repaint = UpdateCursorPosition(self.app.video, x, y)
+  if self.app.moviePlayer.playing then
+    return false
+  end
   
   self.cursor_x = x
   self.cursor_y = y
@@ -457,6 +454,10 @@ function GameUI:onMouseMove(x, y, dx, dy)
 end
 
 function GameUI:onMouseUp(code, x, y)
+  if self.app.moviePlayer.playing then
+    return UI.onMouseUp(self, code, x, y)
+  end
+
   if code == 4 or code == 5 then
     -- Mouse wheel
     local window = self:getWindow(UIFullscreen)
@@ -505,7 +506,9 @@ end
 
 function GameUI:playAnnouncement(name)
   self.ticks_since_last_announcement = 0
-  return UI.playAnnouncement(self, name)
+  if self.app.world:getLocalPlayerHospital():hasStaffedDesk() then
+    UI.playAnnouncement(self, name)
+  end
 end
 
 function GameUI:onTick()
@@ -636,9 +639,21 @@ function GameUI:limitCamera(mode)
   self:scrollMap(0, 0)
 end
 
-function GameUI:makeWallsTransparent(mode)
+--! Applies the current setting for wall transparency to the map
+function GameUI:applyTransparency()
+  self.app.map.th:setWallDrawFlags(self.transparent_walls and 4 or 0)
+end
+
+--! Sets wall transparency to the specified parameter
+--!param mode (boolean) whether to enable or disable wall transparency
+function GameUI:setWallsTransparent(mode)
   self.transparent_walls = mode
-  self.app.map.th:setWallDrawFlags(mode and 4 or 0)
+  self:applyTransparency()
+end
+
+--! Toggles transparency of walls, i.e. enables if currently disabled, and vice versa
+function GameUI:toggleWallsTransparent()
+  self:setWallsTransparent(not self.transparent_walls)
 end
 
 local tutorial_phases
@@ -890,3 +905,19 @@ function GameUI:showBriefing()
   end
   self:addWindow(UIInformation(self, text))
 end
+
+--! Offers a confirmation window to quit the game and return to main menu
+-- NB: overrides UI.quit, do NOT call it from here
+function GameUI:quit()
+  self:addWindow(UIConfirmDialog(self, _S.confirmation.quit, --[[persistable:gameui_confirm_quit]] function()
+    self.app:loadMainMenu()
+  end))
+end
+
+function GameUI:showCheatsWindow()
+  self:addWindow(UICheats(self))
+end
+
+function GameUI:showMenuBar()
+  self.menu_bar:appear()
+end
\ No newline at end of file
