@@ -20,7 +20,7 @@ SOFTWARE. --]]
 
 class "Hospital"
 
-function Hospital:Hospital(world)
+function Hospital:Hospital(world, name)
   self.world = world
   local level_config = world.map.level_config
   local level = world.map.level_number
@@ -39,7 +39,7 @@ function Hospital:Hospital(world)
       self.win_awards = true
     end
   end
-  self.name = os.getenv("USER") or os.getenv("USERNAME") or "PLAYER"
+  self.name = name or "PLAYER"
   -- TODO: Variate initial reputation etc based on level
   -- When playing in free build mode you don't care about money.
   self.balance = not world.free_build_mode and balance or 0
@@ -559,6 +559,22 @@ function Hospital:afterLoad(old, new)
     self:initOwnedPlots()
     self.handymanTasks = {}
   end
+  
+  if old < 54 then
+    local current = self.research.research_policy.specialisation.current
+      if current and not current.dummy and not current.thob and not current.drug then
+        for _, disease_entry in pairs(self.disease_casebook) do
+        if disease_entry.concentrate_research then
+          self.research:concentrateResearch(disease_entry.disease.id)
+          self.research:concentrateResearch(disease_entry.disease.id)
+        end
+      end
+    end
+  end
+
+  if old < 56 then
+    self.research_dep_built = false 
+  end  
 end
 
 function Hospital:countPatients()
@@ -576,7 +592,7 @@ function Hospital:countPatients()
 end
 
 -- A range of checks to help a new player. These are set days apart and will show no more than once a month
-function Hospital:checkFacilites()
+function Hospital:checkFacilities()
   if self:isPlayerHospital() then
     -- Check to see if a staff room has been built
     self.is_staff_room = false
@@ -719,7 +735,24 @@ end
 --! Called each tick, also called 'hours'. Check hours_per_day in
 --! world.lua to see how many times per day this is.
 function Hospital:tick()
+-- add some random background sounds, ringing phones, coughing, belching etc
   self:countPatients()
+  local sounds = {  
+  "ispot001.wav", "ispot002.wav", "ispot003.wav", "ispot004.wav", "ispot005.wav", "ispot006.wav", "ispot007.wav", "ispot008.wav",
+  "ispot009.wav", "ispot010.wav", "ispot011.wav", "ispot012.wav", "ispot013.wav", "ispot014.wav", "ispot015.wav", "ispot016.wav",
+  "ispot017.wav", "ispot018.wav", "ispot019.wav", "ispot020.wav", "ispot021.wav", "ispot022.wav", "ispot023.wav", "ispot024.wav",
+  "ispot025.wav"
+  } -- ispot026 and ispot027 are both toilet related sounds  
+-- wait until there are some patients in the hospital and a room, otherwise you will wonder who is coughing or who is the 
+-- receptionist telephoning! opted for gp as you can't run the hospital without one.  
+  if self:hasRoomOfType("gp") and self.patientcount > 2 then
+    if math.random(1, 100) == 3 then
+      local sound_to_play = sounds[math.random(1, #sounds)]
+      if TheApp.audio:soundExists(sound_to_play) then
+        self.world.ui:playSound(sound_to_play)
+      end
+    end  
+  end    
 end
 
 function Hospital:purchasePlot(plot_number)
@@ -729,9 +762,8 @@ function Hospital:purchasePlot(plot_number)
     if cost <= self.balance then
       self.world:setPlotOwner(plot_number, self:getPlayerIndex())
       table.insert(self.ownedPlots, plot_number)
-      -- Also make sure that the transparent walls setting is used. 
-      -- TODO: This check should be done in C++?
-      self.world.ui:makeWallsTransparent(self.world.ui.transparent_walls)
+      -- Also make sure to apply transparency to the new walls, if required. 
+      self.world.ui:applyTransparency()
       self:spendMoney(cost, _S.transactions.buy_land, cost)
       return true
     end
@@ -823,7 +855,7 @@ function Hospital:onEndDay()
   self.acc_loan_interest = self.acc_loan_interest + pay_this
   self.research:researchCost()
   if self:hasStaffedDesk() then
-    self:checkFacilites()
+    self:checkFacilities()
   end
   self.show_progress_screen_warnings = math.random(1, 3) -- used in progress report to limit warnings
 
@@ -838,10 +870,18 @@ function Hospital:onEndDay()
   -- if there's currently an earthquake going on, possibly give the machines some damage
   if (self.world.active_earthquake) then
     for _, room in pairs(self.world.rooms) do
-      for object, value in pairs(room.objects) do
-        if (object.strength) then
-          if (math.random(0,3) == 1) then
-            object:machineUsed(room)
+      -- Only damage this hospital's objects.
+      if room.hospital == self then -- TODO: For multiplayer?
+        for object, value in pairs(room.objects) do
+          if object.strength then
+            -- The or clause is for backwards compatibility. Then the machine takes one damage each day.
+            if (object.quake_points and object.quake_points > 0) 
+            or object.quake_points == nil then
+              object:machineUsed(room)
+            end
+            if object.quake_points then
+              object.quake_points = object.quake_points - 1
+            end
           end
         end
       end
@@ -984,7 +1024,7 @@ function Hospital:onEndMonth()
     money_out = self.money_out,
     wages = wages,
     balance = self.balance,
-    visitors = self.visitors,
+    visitors = self.num_visitors,
     cures = self.num_cured,
     deaths = self.num_deaths,
     reputation = self.reputation,
@@ -1354,7 +1394,7 @@ function Hospital:hasRoomOfType(type)
   -- Check how many rooms there are.
   local result = false
   for _, room in pairs(self.world.rooms) do
-    if room.hospital == self and room.room_info.id == type then
+    if room.hospital == self and room.room_info.id == type and room.is_active then
       result = (result or 0) + 1
     end
   end
@@ -1513,7 +1553,7 @@ function Hospital:removeHandymanTask(taskIndex, taskType)
     local task = subTable[taskIndex]
     table.remove(subTable, taskIndex)
     if task.assignedHandyman then
-      if taskType ~= "cleaning" and task.object.ticks ~= true then 
+      if task.object.ticks ~= true then 
         task.assignedHandyman:intreruptHandymanTask()
       end
     end
@@ -1644,3 +1684,50 @@ function Hospital:initOwnedPlots()
     end
   end
 end
+
+--! Function that returns true if the room for the given disease
+--! has not been researched yet.
+--! param disease (string): the disease to be checked.
+function Hospital:roomNotYetResearched(disease)
+  local req = self:checkDiseaseRequirements(disease)
+  if type(req) == "table" and #req.rooms > 0 then
+    for i, room_id in ipairs(req.rooms) do
+      if not self.discovered_rooms[self.world.available_rooms[room_id]] then
+        return true
+      end
+    end
+  end
+  return false  
+end
+
+--! Function that returns true if concentrating research on the disease is possible.
+--! @param disease (string): the disease to be checked. 
+function Hospital:canConcentrateResearch(disease)
+  local book = self.disease_casebook
+  if not book[disease].pseudo and self:roomNotYetResearched(disease) then
+    return true
+  end
+  if book[disease].drug then
+    return book[disease].cure_effectiveness < 100
+  end 
+  local room
+  if book[disease].pseudo then
+    room = book[disease].disease.id:sub(6)
+  else
+    room = book[disease].disease.treatment_rooms[#book[disease].disease.treatment_rooms]
+  end
+  local research_progress = self.research.research_progress
+  local object_type
+  for obj, _ in pairs(self.world.available_rooms[room].objects_needed) do
+    if self.world.object_types[obj].default_strength then
+      object_type = obj
+      break
+    end
+  end
+
+  if object_type then
+    local progress = research_progress[self.world.object_types[object_type]]  
+    return progress.start_strength < self.world.map.level_config.gbv.MaxObjectStrength
+  end
+  return false
+end
