@@ -71,6 +71,7 @@ menu_options = {
   edge_scrolling = "  EDGE SCROLLING  ",
   settings = "  SETTINGS  ",
   adviser_disabled = "  ADVISER  ",
+  warmth_colors = "  WARMTH COLOURS  ",
 }
 
 menu_options_game_speed = {
@@ -82,6 +83,26 @@ menu_options_game_speed = {
   and_then_some_more  = "  (5) AND THEN SOME MORE  ",
 }
 
+menu_options_warmth_colors = {
+  choice_1 = "  RED  ",
+  choice_2 = "  BLUE GREEN RED  ",
+  choice_3 = "  YELLOW ORANGE RED  ",
+}
+
+-- Add F-keys to entries in charts menu (except briefing), also town_map was added.
+menu_charts = {
+  bank_manager  = "  (F1) BANK MANAGER  ",
+  statement     = "  (F2) STATEMENT  ",
+  staff_listing = "  (F3) STAFF LISTING  ",
+  town_map      = "  (F4) TOWN MAP  ",
+  casebook      = "  (F5) CASEBOOK  ",
+  research      = "  (F6) RESEARCH  ",
+  status        = "  (F7) STATUS  ",
+  graphs        = "  (F8) GRAPHS  ",
+  policy        = "  (F9) POLICY  ",
+}
+
+
 -- The demo does not contain this string
 menu_file.restart = "  RESTART  "
 
@@ -90,8 +111,8 @@ menu_debug = {
   transparent_walls           = "  (X) TRANSPARENT WALLS  ",
   limit_camera                = "  LIMIT CAMERA  ",
   disable_salary_raise        = "  DISABLE SALARY RAISE  ",
-  make_debug_fax              = "  (F8) MAKE DEBUG FAX  ",
-  make_debug_patient          = "  (F9) MAKE DEBUG PATIENT  ",
+  make_debug_fax              = "  MAKE DEBUG FAX  ",
+  make_debug_patient          = "  MAKE DEBUG PATIENT  ",
   cheats                      = "  (F11) CHEATS  ",
   lua_console                 = "  (F12) LUA CONSOLE  ",
   calls_dispatcher            = "  CALLS DISPATCHER  ",
@@ -127,7 +148,9 @@ adviser = {
     falling_3 = "Ouch, that had to hurt, someone call a Doctor!",
     falling_4 = "This is an Hospital, not a Theme Park!",
     falling_5 = "This is not the place for knocking people over, they're ill you know!",
-    falling_6 = "This is not a bowling alley, sick people should not be treated like that!"
+    falling_6 = "This is not a bowling alley, sick people should not be treated like that!",
+    research_screen_open_1 = "You have to build a Research Department before you can access the Reasearch screen.",
+    research_screen_open_2 = "Research is disabled for the current level.",
   },
   cheats = {  
     th_cheat = "Congratulations, you have unlocked cheats!",
@@ -203,7 +226,7 @@ tooltip.main_menu = {
 }
 
 load_game_window = {
-  caption = "Load Game",
+  caption = "Load Game (%1%)",
 }
 
 tooltip.load_game_window = {
@@ -223,7 +246,7 @@ tooltip.custom_game_window = {
 }
 
 save_game_window = {
-  caption = "Save Game",
+  caption = "Save Game (%1%)",
   new_save_game = "New Savegame",
 }
 
@@ -245,18 +268,48 @@ tooltip.menu_list_window = {
 }
 
 options_window = {
+  caption = "Options",
+  option_on = "On",
+  option_off = "Off",
   fullscreen = "Fullscreen",
+  resolution = "Resolution",
+  custom_resolution = "Custom...",
   width = "Width",
   height = "Height",
-  change_resolution = "Change resolution",
+  apply = "Apply",
+  cancel = "Cancel",
+  data_location = "Data location",
+  font_location = "Font location",
   browse = "Browse...",
   new_th_directory = "Here you can specify a new Theme Hospital installation directory. As soon as you choose the new directory the game will be restarted.",
+  language = "Game language",
   cancel = "Cancel",
   back = "Back",
 }
 
-tooltip.handyman_window = {
-  parcel_select = "The parcel where the handyman accepts tasks, click to change setting"
+tooltip.options_window = {
+  fullscreen = "Whether the game should run in fullscreen or windowed mode",
+  fullscreen_button = "Click to toggle fullscreen mode",
+  resolution = "The resolution the game should run in",
+  select_resolution = "Select a new resolution",
+  width = "Enter desired screen width",
+  height = "Enter desired screen height",
+  apply = "Apply the entered resolution",
+  cancel = "Return without changing the resolution",
+  data_location = "The directory of the original Theme Hospital installation, which is required to run CorsixTH",
+  font_location = "Location of a font file that is capable of displaying Unicode characters required by your language. If this is not specified you will not be able to choose languages that need more characters than the original game can supply. Example: Russian and Chinese",
+  language = "The language texts in the game will appear in",
+  select_language = "Select the game language",
+  language_dropdown_item = "Choose %s as language",
+  original_path = "The currently chosen directory of the original Theme Hospital installation",
+  browse = "Browse for another location of a Theme Hospital installation (current location: %1%)",
+  browse_font = "Browse for another font file (current location: %1%)",
+  no_font_specified = "No location specified yet!",
+  back = "Close the options window",
+}
+
+font_location_window = {
+  caption = "Choose font (%1%)",
 }
 
 handyman_window = {
@@ -264,31 +317,32 @@ handyman_window = {
   parcel = "Parcel"
 }
 
-tooltip.options_window = {
-  fullscreen_button = "Click to toggle fullscreen mode",
-  width = "Enter desired screen width",
-  height = "Enter desired screen height",
-  change_resolution = "Change the window resolution to the dimensions entered on the left",
-  language = "Select %s as language",
-  original_path = "The currently chosen directory of the original Theme Hospital installation",
-  browse = "Browse for another location of a Theme Hospital installation",
-  back = "Close the options window",
+tooltip.handyman_window = {
+  parcel_select = "The parcel where the handyman accepts tasks, click to change setting"
 }
 
 new_game_window = {
+  caption = "Campaign",
+  player_name = "Player name",
+  option_on = "On",
+  option_off = "Off",
+  difficulty = "Difficulty",
   easy = "Junior (Easy)",
   medium = "Doctor (Medium)",
   hard = "Consultant (Hard)",
   tutorial = "Tutorial",
+  start = "Start",
   cancel = "Cancel",
 }
 
 tooltip.new_game_window = {
+  player_name = "Enter the name you wish to be referred to as in the game",
+  difficulty = "Select the difficulty level you want to play the game in",
   easy = "If you are new to simulation games this is the option for you",
   medium = "This is the middle way to go if you are unsure what to choose",
   hard = "If you are used to this kind of game and want more of a challenge, pick this option",
   tutorial = "If you want some help to get started once in the game, tick this box",
-  tutorial = "Tutorial",
+  start = "Start the game with the chosen settings",
   cancel = "Oh, I didn't really mean to start a new game!",
 }
 
@@ -329,7 +383,9 @@ information = {
     reputation = "Your reputation fell below %d.",
     balance = "Your bank balance fell below %d.",
     percentage_killed = "You killed more than %d percent of the patients.",
+    cheat = "This was your choice or did you select the wrong button? So you can't even cheat correctly, not that funny huh?",
   },
+  cheat_not_possible = "Cannot use that cheat on this level. You even fail to cheat, not that funny huh?",
 }
 
 tooltip.information = {
@@ -434,3 +490,10 @@ tooltip.calls_dispatcher = {
   assigned = "This box is marked if someone is assigned to the corresponding task.",
   close = "Close the calls dispatcher dialog",
 }
+
+
+--------------------------------  UNUSED  -----------------------------------
+------------------- (kept for backwards compatibility) ----------------------
+
+options_window.change_resolution = "Change resolution"
+tooltip.options_window.change_resolution = "Change the window resolution to the dimensions entered on the left"
