@@ -33,19 +33,20 @@ adviser.warnings.money_low = "Stai finendo i soldi!"
 fax.emergency.cure_not_possible_build = "E' necessario costruire un %s"
 fax.emergency.cure_not_possible_build_and_employ = "E' necessario costruire un %s e assunere un %s"
 
--- new strings
+-------------------------------  NEW STRINGS  -------------------------------
 date_format = {
   daymonth = "%1% %2:months%",
 }
+
 object.litter = "Spazzatura"
-tooltip.objects.litter = utf8 "Spazzatura: Lasciata sul pavimento da un paziente perché non ha trovato un cestino in cui gettarla."
+tooltip.objects.litter = "Spazzatura: Lasciata sul pavimento da un paziente perché non ha trovato un cestino in cui gettarla."
 
 tooltip.fax.close = "Chiudi questa finestra senza cancellare il messaggio"
 tooltip.message.button = "Click sinistro per aprire il messaggio"
 tooltip.message.button_dismiss = "Click sinistro per aprire il messaggio, click destro per eliminarlo"
 tooltip.casebook.cure_requirement.hire_staff = "Hai bisogno di assumere personale per somministrare questa cura"
 tooltip.casebook.cure_type.unknown = "Ancora non sei a conoscenza di un modo per curare questa malattia"
-tooltip.research_policy.no_research = utf8 "Non c'è nessuna ricerca in corso in questa categoria al momento"
+tooltip.research_policy.no_research = "Non c'è nessuna ricerca in corso in questa categoria al momento"
 tooltip.research_policy.research_progress = "Progresso verso una nuova scoperta in questa categoria: %1%/%2%"
 
 menu_options = {
@@ -53,6 +54,7 @@ menu_options = {
   edge_scrolling = "  SCORRIMENTO AI LATI  ",
   settings = "  IMPOSTAZIONI  ",
   adviser_disabled = "  CONSIGLIERE  ",
+  warmth_colors = "  COLORI RISCALDAMENTO  ",
 }
 
 menu_options_game_speed = {
@@ -64,6 +66,26 @@ menu_options_game_speed = {
   and_then_some_more  = "  (5) E ANCORA DI PIU'  ",
 }
 
+menu_options_warmth_colors = {
+  choice_1 = "  ROSSO  ",
+  choice_2 = "  BLU VERDE ROSSO  ",
+  choice_3 = "  GIALLO ARANCIONE ROSSO  ",
+}
+
+-- Add F-keys to entries in charts menu (except briefing), also town_map was added.
+menu_charts = {
+  bank_manager  = "  (F1) BANCA  ",
+  statement     = "  (F2) RENDICONTO  ",
+  staff_listing = "  (F3) PERSONALE  ",
+  town_map      = "  (F4) MAPPA CITTADINA  ",
+  casebook      = "  (F5) REGISTRO CURE  ",
+  research      = "  (F6) RICERCA  ",
+  status        = "  (F7) RIEPILOGO  ",
+  graphs        = "  (F8) GRAFICI  ",
+  policy        = "  (F9) GESTIONE  ",  
+}
+
+
 -- The demo does not contain this string
 menu_file.restart = "  RIAVVIA  "
 
@@ -72,8 +94,8 @@ menu_debug = {
   transparent_walls           = "  (X) MURA TRASPARENTI  ",
   limit_camera                = "  LIMITA TELECAMERA  ",
   disable_salary_raise        = "  DISABILITA AUMENTI DI SALARIO  ",
-  make_debug_fax              = "  (F8) CREA FAX DI DEBUG  ",
-  make_debug_patient          = "  (F9) CREA UN PAZIENTE DI DEBUG  ",
+  make_debug_fax              = "  CREA FAX DI DEBUG  ",
+  make_debug_patient          = "  CREA UN PAZIENTE DI DEBUG  ",
   cheats                      = "  (F11) CHEAT  ",
   lua_console                 = "  (F12) CONSOLE LUA  ",
   calls_dispatcher            = "  GESTORE CHIAMATE  ",
@@ -82,6 +104,7 @@ menu_debug = {
   map_overlay                 = "  MAPPA IN SOVRAPPOSIZIONE  ",
   sprite_viewer               = "  VISUALIZZATORE SPRITE  ",
 }
+
 menu_debug_overlay = {
   none                        = "  NESSUN OVERLAY  ",
   flags                       = "  FLAGS  ",
@@ -94,7 +117,7 @@ menu_debug_overlay = {
   byte_5                      = "  BYTE 5  ",
   byte_6                      = "  BYTE 6  ",
   byte_7                      = "  BYTE 7  ",
-  parcel                      = "  PARCEL  ",
+  parcel                      = "  LOTTO  ",
 }
 adviser = {
   room_forbidden_non_reachable_parts = "Mettere la stanza in questa posizione risulterebbe nel blocco dell'accesso ad alcune parti dell'ospedale.",
@@ -102,14 +125,16 @@ adviser = {
     no_desk = "Prima o poi dovrai costruire un banco di accettazione ed assumere una receptionist!",
     no_desk_1 = "Se vuoi che i pazienti vengano nel tuo ospedale dovrai assumere una receptionist e costruirle una scrivania dove farla lavorare!",
     no_desk_2 = "Ben fatto, deve essere un record mondiale: quasi un anno e nessun paziente! Se vuoi continuare come Manager di questo ospedale dovrai assumere una receptionist e costruire un banco di accettazione dove farla lavorare!",
-    no_desk_3 = utf8 "Grandioso, quasi un anno e ancora non hai personale all'accettazione! Come ti aspetti di trovare pazienti, ora vedi di rimediare e di non fare più casini!",
+    no_desk_3 = "Grandioso, quasi un anno e ancora non hai personale all'accettazione! Come ti aspetti di trovare pazienti, ora vedi di rimediare e di non fare più casini!",
     cannot_afford = "Non hai abbastanza soldi in banca per assumere questa persona!", -- I can't see anything like this in the original strings
-    falling_1 = utf8 "Ehi! Non è divertente, attento a dove clicchi: qualcuno potrebbe farsi male!",
-    falling_2 = utf8 "Basta fare casini, a te piacerebbe?",
+    falling_1 = "Ehi! Non è divertente, attento a dove clicchi: qualcuno potrebbe farsi male!",
+    falling_2 = "Basta fare casini, a te piacerebbe?",
     falling_3 = "Ahi, deve far male, qualcuno chiami un dottore!",
-    falling_4 = utf8 "Questo è un ospedale, non un parco giochi!",
-    falling_5 = utf8 "Non è il luogo adatto per far cadere le persone, sono malate sai!",
-    falling_6 = utf8 "Non è una sala da bowling, i malati non dovrebbero essere trattati così!"
+    falling_4 = "Questo è un ospedale, non un parco giochi!",
+    falling_5 = "Non è il luogo adatto per far cadere le persone, sono malate sai!",
+    falling_6 = "Non è una sala da bowling, i malati non dovrebbero essere trattati così!",
+	research_screen_open_1 = "Devi costruire un Reparto Ricerca prima di poter accedere alla schermata Ricerca.",
+    research_screen_open_2 = "La Ricerca è disabilitata in questo livello.",
   },
   cheats = {  
     th_cheat = "Congratulazioni, hai sbloccato i cheat!",
@@ -134,15 +159,15 @@ fax = {
    choices = {
     return_to_main_menu = "Ritorna al menu principale",
     accept_new_level = "Vai al livello successivo",
-    decline_new_level = utf8 "Continua a giocare un altro po'",
+    decline_new_level = "Continua a giocare un altro po'",
   },
   emergency = {
-    num_disease_singular = utf8 "C'è una persona con %s che richiede la tua immediata attenzione.",
-    free_build = utf8 "Se hai successo la tua reputazione aumenterà, ma se fallisci la tua reputazione verrà intaccata pesantemente.",
+    num_disease_singular = "C'è una persona con %s che richiede la tua immediata attenzione.",
+    free_build = "Se hai successo la tua reputazione aumenterà, ma se fallisci la tua reputazione verrà intaccata pesantemente.",
   },
   vip_visit_result = {
     remarks = {
-      free_build = utf8 {
+      free_build = {
         "Hai proprio un bell'ospedale! Anche se non è difficile ottenerlo con fondi illimitati, eh?",
         "Non sono un economista, ma penso che anch'io avrei potuto dirigere quest'ospedale, non so se mi spiego...",
         "Un ospedale molto ben gestito. Attento alla crisi economica però! Ah, giusto... non te ne sei dovuto preoccupare.",
@@ -185,13 +210,13 @@ tooltip.main_menu = {
 }
 
 load_game_window = {
-  caption = "Carica Partita",
+  caption = "Carica Partita (%1%)",
 }
 
 tooltip.load_game_window = {
   load_game = "Carica la partita %s",
   load_game_number = "Carica la partita %d",
-  load_autosave = "Carica l'ultimo autosalvataggio",
+  load_autosave = "Carica autosalvataggio",
 }
 
 custom_game_window = {
@@ -201,11 +226,11 @@ custom_game_window = {
 
 tooltip.custom_game_window = {
   start_game_with_name = "Carica il livello %s",
-  free_build = utf8 "Spunta questa casella per giocare senza soldi, né vittoria o sconfitta",
+  free_build = "Spunta questa casella per giocare senza soldi, né vittoria o sconfitta",
 }
 
 save_game_window = {
-  caption = "Salva Partita",
+  caption = "Salva Partita (%1%)",
   new_save_game = "Nuovo Salvataggio",
 }
 
@@ -225,51 +250,83 @@ tooltip.menu_list_window = {
   save_date = "Clicca qui per ordinare la lista in base alla data dell'ultima modifica",
   back = "Chiudi questa finestra",
 }
+
 -- Width / height's translation doesn't fit - had to write "larghezza" and "altezza" shorter
 options_window = {
+  caption = "Opzioni",
+  option_on = "On",
+  option_off = "Off",
   fullscreen = "Schermo intero",
+  resolution = "Risoluzione",
+  custom_resolution = "Personalizzata...",
   width = "Largh",
   height = "Alt",
-  change_resolution = "Cambia risoluzione",
+  apply = "Applica",
+  data_location = "Posizione dati",
+  font_location = "Posizione font",
   browse = "Sfoglia...",
-  new_th_directory = utf8 "Qui puoi specificare una nuova cartella di installazione di Theme Hospital. Appena scegli la nuova cartella il gioco verrà riavviato.",
+  new_th_directory = "Qui puoi specificare una nuova cartella di installazione di Theme Hospital. Appena scegli la nuova cartella il gioco verrà riavviato.",
+  language = "Lingua del gioco",
   cancel = "Cancella",
   back = "Indietro",
 }
 
-tooltip.handyman_window = {
-  parcel_select = utf8 "Il lotto dove l'inserviente può operare. Clicca per cambiarlo."
-}
- 
-handyman_window = {
-  all_parcels = "Tutti i lotti",
-  parcel = "Lotto"
-}  
-
 tooltip.options_window = {
-  fullscreen_button = utf8 "Clicca per selezionare o deselezionare la modalità a schermo intero",
+  fullscreen = "Decide se il gioco verrà eseguito a tutto schermo o in finestra",
+  fullscreen_button = "Clicca per selezionare o deselezionare la modalità a schermo intero",
+  resolution = "La risoluzione a cui il gioco dovrebbe essere eseguito",
+  select_resolution = "Seleziona una nuova risoluzione",
   width = "Inserisci la larghezza dello schermo desiderata",
-  height = utf8 "Inserisci l'altezza dello schermo desiderata",
-  change_resolution = "Cambia la risoluzione della finestra alle dimensioni inserite a sinistra",
-  language = "Seleziona %s come lingua",
-  original_path = utf8 "La cartella dell'installazione di Theme Hospital originale attualmente selezionata",
-  browse = utf8 "Seleziona la cartella di un'altra installazione di Theme Hospital",
+  height = "Inserisci l'altezza dello schermo desiderata",
+  apply = "Applica la risoluzione inserita",
+  cancel = "Esci senza cambiare la risoluzione",
+  data_location = "La cartella dove è installato il Theme Hospital originale, che è richiesto per eseguire CorsixTH",
+  font_location = "La posizione di un font che è in grado di mostrare caratteri Unicode richiesti dalla tua lingua. Se non specificata, non potrai scegliere lingue che hanno bisogno di più caratteri rispetto a quelli di cui dispone il gioco originale. Esempio: Russo e Cinese",
+  language = "La lingua in cui verrà mostrato il testo",
+  select_language = "Seleziona la lingua del gioco",
+  language_dropdown_item = "Seleziona %s come lingua",
+  original_path = "La cartella dell'installazione di Theme Hospital originale attualmente selezionata",
+  browse = "Seleziona un'altra cartella di installazione di Theme Hospital (posizione corrente: %1%)",
+  browse_font = "Seleziona un altro file font (posizione corrente: %1%)",
+  no_font_specified = "Non hai ancora specificato alcuna posizione!",
   back = "Chiudi la finestra delle opzioni",
 }
 
+font_location_window = {
+  caption = "Scegli il font (%1%)",
+}
+
+handyman_window = {
+  all_parcels = "Tutti i lotti",
+  parcel = "Lotto"
+} 
+
+tooltip.handyman_window = {
+  parcel_select = "Il lotto dove l'inserviente può operare. Clicca per cambiarlo."
+} 
+
 new_game_window = {
+  caption = "Campagna",
+  player_name = "Nome del giocatore",
+  option_on = "On",
+  option_off = "Off",
+  difficulty = "Difficoltà",
   easy = "Assistente (Facile)",
   medium = "Dottore (Medio)",
   hard = "Consulente (Difficile)",
   tutorial = "Tutorial",
+  start = "Comincia",
   cancel = "Cancella",
 }
 
 tooltip.new_game_window = {
-  easy = utf8 "Se non sei pratico di simulatori questa è l'opzione per te",
-  medium = utf8 "Questa è la via di mezzo se non sei sicuro su cosa scegliere",
-  hard = utf8 "Se sei abituato a questo tipo di giochi e vuoi una sfida più impegnativa, scegli questa opzione",
+  player_name = "Inserisci il nome col quale vuoi essere chiamato nel gioco",
+  difficulty = "Seleziona il livello di difficoltà a cui vuoi giocare",
+  easy = "Se non sei pratico di simulatori questa è l'opzione per te",
+  medium = "Questa è la via di mezzo se non sei sicuro su cosa scegliere",
+  hard = "Se sei abituato a questo tipo di giochi e vuoi una sfida più impegnativa, scegli questa opzione",
   tutorial = "Se vuoi aiuto per cominciare mentre sei in gioco, spunta questa casella",
+  start = "Avvia il gioco con le impostazioni scelte",
   cancel = "Oh, non volevo davvero cominciare una nuova partita!",
 }
 
@@ -295,23 +352,25 @@ errors = {
 }
 
 confirmation = {
-  needs_restart = utf8 "Cambiare questa impostazione richiede che CorsixTH sia riavviato. Ogni progresso non salvato sarà perduto. Sei sicuro di volerlo fare?",
-  abort_edit_room = utf8 "Stai attualmente costruendo o modificando una stanza. Se tutti gli oggetti richiesti sono stati posizionati sarà completata, altrimenti sarà cancellata. Continuare?",
-  restart_level = "Sei sicuro di voler riavviare il livello?"
+  needs_restart = "Cambiare questa impostazione richiede che CorsixTH sia riavviato. Ogni progresso non salvato sarà perduto. Sei sicuro di volerlo fare?",
+  abort_edit_room = "Stai attualmente costruendo o modificando una stanza. Se tutti gli oggetti richiesti sono stati posizionati sarà completata, altrimenti sarà cancellata. Continuare?",
+  restart_level = "Sei sicuro di voler riavviare il livello?",
 }
 
 information = {
   custom_game = "Benvenuto in CorsixTH. Divertiti con questa mappa personalizzata!",
   no_custom_game_in_demo = "Spiacente, ma nella versione demo non puoi giocare mappe personalizzate.",
-  cannot_restart = utf8 "Sfortunatamente questa mappa personalizzata è stata salvata prima che venisse implementata la funzione per riavviare.",
-  very_old_save = utf8 "Il gioco è stato molto aggiornato da quando hai avviato questo livello. Per assicurarti che tutto funzioni come dovrebbe prendi in considerazione l'idea di riavviarlo.",
+  cannot_restart = "Sfortunatamente questa mappa personalizzata è stata salvata prima che venisse implementata la funzione per riavviare.",
+  very_old_save = "Il gioco è stato molto aggiornato da quando hai avviato questo livello. Per assicurarti che tutto funzioni come dovrebbe prendi in considerazione l'idea di riavviarlo.",
   level_lost = {
-    utf8 "Peccato! Hai perso il livello. Avrai più fortuna la prossima volta!",
-    utf8 "Hai perso perchè:",
-    reputation = utf8 "La tua reputazione è scesa sotto %d.",
-    balance = utf8 "Il tuo conto in banca è sceso sotto %d.",
-    percentage_killed = utf8 "Hai ucciso più del %d dei pazienti.",
+    "Peccato! Hai perso il livello. Avrai più fortuna la prossima volta!",
+    "Hai perso perchè:",
+    reputation = "La tua reputazione è scesa sotto %d.",
+    balance = "Il tuo conto in banca è sceso sotto %d.",
+    percentage_killed = "Hai ucciso più del %d dei pazienti.",
+	cheat = "È stata una tua scelta o hai selezionato il pulsante sbagliato? Non riesci nemmeno a barare correttamente, non è così divertente, eh?",
   },
+  cheat_not_possible = "Non puoi usare cheat in questo livello. Fallisci anche nel barare, non è così divertente, eh?",
 }
 
 tooltip.information = {
@@ -320,25 +379,25 @@ tooltip.information = {
 
 totd_window = {
   tips = {
-    utf8 "Ogni ospedale per funzionare ha bisogno di alcune strutture di base. Inizia con una reception e un ambulatorio, e il personale necessario. Una volta iniziato, dipenderà tutto dal tipo di pazienti che visiteranno il tuo ospedale. Qualche stanza per le diagnosi e una farmacia sono una buona scelta per iniziare.",
-    utf8 "I macchinari come la Pompa hanno bisogno di manutenzione più o meno costante. Assumi qualche tuttofare per ripararle, o rischierai che i pazienti e il tuo staff si facciano male.",
+    "Ogni ospedale per funzionare ha bisogno di alcune strutture di base. Inizia con una reception e un ambulatorio, e il personale necessario. Una volta iniziato, dipenderà tutto dal tipo di pazienti che visiteranno il tuo ospedale. Qualche stanza per le diagnosi e una farmacia sono una buona scelta per iniziare.",
+    "I macchinari come la Pompa hanno bisogno di manutenzione più o meno costante. Assumi qualche tuttofare per ripararle, o rischierai che i pazienti e il tuo staff si facciano male.",
     "Il tuo staff lavora duramente, e ogni tanto ha bisogno di riposare. Costruisci una sala del personale per loro.",
     "Ricordati di fornire il tuo ospedale di un impianto di riscaldamento funzionante, o lo staff ed i pazienti rimarranno infelici e infreddoliti.",
-    utf8 "Il livello di competenza influenza in maniera enorme la qualità e la velocità delle diagnosi. Assegnando un dottore molto abile al tuo ambulatorio non avrai bisogno di costruire molte strutture di diagnosi addizionali.",
-    utf8 "Assistenti e dottori possono aumentare il loro livello di competenza imparando da un consulente nella sala tirocinio. Se il consulente è anche uno specialista (chirurgo, psichiatra e/o ricercatore), passerà le sue conoscente ai suoi studenti.",
+    "Il livello di competenza influenza in maniera enorme la qualità e la velocità delle diagnosi. Assegnando un dottore molto abile al tuo ambulatorio non avrai bisogno di costruire molte strutture di diagnosi addizionali.",
+    "Assistenti e dottori possono aumentare il loro livello di competenza imparando da un consulente nella sala tirocinio. Se il consulente è anche uno specialista (chirurgo, psichiatra e/o ricercatore), passerà le sue conoscente ai suoi studenti.",
     "Hai provato a digitare il numero di emergenza europea (112) nel fax? Assicurati di avere l'audio attivato!",
     "Il menu d'opzioni non è ancora implementato, ma puoi regolare le impostazioni modificando il file config.txt nella directory di gioco.",
-    utf8 "Hai selezionato il tuo linguaggio, ma tutto è in inglese? Aiutaci a convertire il gioco in più linguaggi!",
+    "Hai selezionato il tuo linguaggio, ma tutto è in inglese? Aiutaci a convertire il gioco in più linguaggi!",
     "Il team di CorsixTH sta cercando rinforzi! Sei interessato in programmare, tradurre o creare nuovi elementi grafici per CorsixTH? Contattaci nei forum, tramite mail o sul canale IRC (corsix-th su freenode).",
     "Trovato un bug? Vuoi segnalare un errore di qualsiasi genere? Inviaci un rapporto su ciò che hai trovato al nostro bug tracker: th-issues.corsix.org",
     "Ogni livello ha degli obiettivi da raggiungere prima di poter passare al successivo. Controlla la finestra del riepilogo per vedere a che punto sei.",
     "Se vuoi modificare o rimuovere una stanza esistente, puoi farlo con il tasto modifica stanza nella barra degli strumenti in basso.",
-    utf8 "In un'orda di pazienti in attesa, puoi vedere velocemente chi sta aspettando il proprio turno per una stanza particolare spostando il mouse sulla stanza.",
-    utf8 "Clicca sulla porta di una stanza per vederne la coda. Puoi fare diverse cose utili, come riordinare la coda o mandare il paziente in un'altra stanza.",
-    utf8 "Se il personale è infelice chiederà spesso aumenti di salario. Assicurati che il tuo staff stia lavorando in un'ambiente di lavoro confortevole per evitare che accada.",
-    utf8 "I pazienti avranno sete durante le attese, soprattutto se alzi il riscaldamento! Piazza i distributori di bevande in posizioni strategiche per un po' di guadagni extra. ",
-    utf8 "Puoi cancellare prematuramente il processo di diagnosi per un paziente e deciderne la cura se hai già incontrato la malattia. Fai attenzione però, dato che fare ciò può incrementare il rischio di una cura sbagliata, risultando nella morte del paziente.",
-    utf8 "Le emergenze possono essere una buona fonte di guadagno extra, sempre che tu abbia i mezzi sufficienti a gestire l'emergenza in tempo.",
+    "In un'orda di pazienti in attesa, puoi vedere velocemente chi sta aspettando il proprio turno per una stanza particolare spostando il mouse sulla stanza.",
+    "Clicca sulla porta di una stanza per vederne la coda. Puoi fare diverse cose utili, come riordinare la coda o mandare il paziente in un'altra stanza.",
+    "Se il personale è infelice chiederà spesso aumenti di salario. Assicurati che il tuo staff stia lavorando in un'ambiente di lavoro confortevole per evitare che accada.",
+    "I pazienti avranno sete durante le attese, soprattutto se alzi il riscaldamento! Piazza i distributori di bevande in posizioni strategiche per un po' di guadagni extra. ",
+    "Puoi cancellare prematuramente il processo di diagnosi per un paziente e deciderne la cura se hai già incontrato la malattia. Fai attenzione però, dato che fare ciò può incrementare il rischio di una cura sbagliata, risultando nella morte del paziente.",
+    "Le emergenze possono essere una buona fonte di guadagno extra, sempre che tu abbia i mezzi sufficienti a gestire l'emergenza in tempo.",
   },
   previous = "Suggerimento Precedente",
   next = "Suggerimento Successivo",
@@ -358,7 +417,7 @@ cheats_window = {
   warning = "Attenzione: Non riceverai alcun punto bonus alla fine del livello se usi i cheat!",
   cheated = {
     no = "Cheat usati: No",
-    yes = utf8 "Cheats usati: Sì",
+    yes = "Cheats usati: Sì",
   },
   cheats = {
     money = "Cheat soldi",
@@ -380,7 +439,7 @@ tooltip.cheats_window = {
   cheats = {
     money = "Aggiunge 10.000 al tuo conto in banca.",
     all_research = "Completa tutte le ricerche.",
-    emergency = utf8 "Crea un'emergenza.",
+    emergency = "Crea un'emergenza.",
     vip = "Crea un VIP.",
     earthquake = "Crea un terremoto.",
     create_patient = "Crea un Paziente sul bordo della mappa.",
@@ -393,8 +452,8 @@ tooltip.cheats_window = {
 
 introduction_texts = {
   demo = {
-    utf8 "Benvenuto nell'ospedale demo!",
-    utf8 "Sfortunatamente la versione demo contiene solo questo livello (oltre ai livelli personalizzati). Ad ogni modo c'è abbastanza da fare per tenerti occupato per un bel po'!",
+    "Benvenuto nell'ospedale demo!",
+    "Sfortunatamente la versione demo contiene solo questo livello (oltre ai livelli personalizzati). Ad ogni modo c'è abbastanza da fare per tenerti occupato per un bel po'!",
     "Incontrerai diverse malattie che richiederanno diverse cliniche per essere curate. Ogni tanto potrebbero presentarsi delle emergenze. E avrai bisogno di ricercare nuove strumentazioni tramite il centro ricerche.",
     "Il tuo obiettivo è di guadagnare $100,000, avere un ospedale che valga $70,000 e una reputazione di 700, oltre che curare almeno il 75% dei tuoi pazienti.",
     "Assicurati che la tua reputazione non scenda al di sotto di 300 e di non uccidere più del 40% dei tuoi pazienti, o perderai.",
@@ -417,6 +476,13 @@ tooltip.calls_dispatcher = {
   close = "Chiude la finestra del gestore chiamate",
 }
 
+
+--------------------------------  UNUSED  -----------------------------------
+------------------- (kept for backwards compatibility) ----------------------
+
+options_window.change_resolution = "Cambia risoluzione"
+tooltip.options_window.change_resolution = "Cambia la risoluzione della finestra con le dimensioni inserite a sinistra"
+
 -- I added those lines because I didn't like 'em to show up in every diff dump!
 original_credits[302] = ","
 original_credits[303] = "Steve Fitton"
