@@ -92,13 +92,21 @@ function UI:initKeyAndButtonCodes()
     down = 274,
     right = 275,
     left = 276,
+    f1 = 282,
+    f2 = 283,
+    f3 = 284,
     f4 = 285,
+    f5 = 286,
+    f6 = 287,
+    f7 = 288,
     f8 = 289,
     f9 = 290,
     f10 = 291,
     f11 = 292,
     f12 = 293,
     enter = 13,
+    home = 278,
+    end_key = 279,
     shift = {303, 304},
     ctrl = {305, 306},
     alt = {307, 308, 313},
@@ -193,6 +201,64 @@ function UI:UI(app, minimal)
   
   self:setCursor(self.default_cursor)
   
+  -- to avoid a bug which causes open fullscreen windows to display incorrectly, load
+  -- the sprite sheet associated with all fullscreen windows so they are correctly cached.
+  -- Darrell: Only do this if we have a valid data directory otherwise we won't be able to 
+  -- display the directory browser to even find the data directory.
+  -- Edvin: Also, the demo does not contain any of the dialogs.
+  if self.app.good_install_folder and not self.app.using_demo_files then
+    local gfx = self.app.gfx
+    local palette
+    -- load drug casebook sprite table
+    palette = gfx:loadPalette("QData", "DrugN01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "DrugN02V", true, palette)
+    -- load fax sprite table
+    palette = gfx:loadPalette("QData", "Fax01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Fax02V", true, palette)
+    -- load town map sprite table
+    palette = gfx:loadPalette("QData", "Town01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Town02V", true, palette)
+    -- load hospital policy sprite table
+    palette = gfx:loadPalette("QData", "Pol01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Pol02V", true, palette)
+    -- load bank manager sprite table
+    palette = gfx:loadPalette("QData", "Bank01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Bank02V", true, palette)
+    -- load research screen sprite table
+    palette = gfx:loadPalette("QData", "Res01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Res02V", true, palette)
+    -- load progress report sprite table
+    palette = gfx:loadPalette("QData", "Rep01V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Rep02V", true, palette)
+    -- load annual report sprite table
+    palette = gfx:loadPalette("QData", "Award02V.pal")
+    palette:setEntry(255, 0xFF, 0x00, 0xFF) -- Make index 255 transparent
+    gfx:loadSpriteTable("QData", "Award03V", true, palette)
+  end
+  
+  self:setupGlobalKeyHandlers()
+end
+
+function UI:setupGlobalKeyHandlers()
+  -- Add some global keyhandlers
+  self:addKeyHandler("esc", self, self.closeWindow)
+  self:addKeyHandler("esc", self, self.stopMovie)
+  self:addKeyHandler(" ", self, self.stopMovie)
+  self:addKeyHandler({"ctrl", "s"}, self, self.makeScreenshot)
+  self:addKeyHandler({"alt", "enter"}, self, self.toggleFullscreen)
+  self:addKeyHandler({"alt", "f4"}, self, self.quit)
+  self:addKeyHandler("f10", self, self.resetApp)
+  
+  if self.app.config.debug then
+    self:addKeyHandler("f12", self, self.showLuaConsole)
+  end
 end
 
 -- Used for everything except music and announcements
@@ -279,19 +345,23 @@ function UI:draw(canvas)
 end
 
 --! Register a key handler / hotkey for a window.
---!param key (string) The keyboard key which should trigger the callback (for
--- example, "left" or "z" or "F9").
+--!param keys (string or table) The keyboard key which should trigger the callback (for
+-- example, "left" or "z" or "F9"), or a list with modifier(s) and the key (e.g. {"ctrl", "s"}).
 --!param window (Window) The UI window which should receive the callback.
 --!param callback (function) The method to be called on `window` when `key` is
 -- pressed.
 --!param ... Additional arguments to `callback`.
-function UI:addKeyHandler(key, window, callback, ...)
-  key = key:lower()
+function UI:addKeyHandler(keys, window, callback, ...)
+  keys = (type(keys) == "table") and keys or {keys}
+
+  local key = table.remove(keys, #keys):lower()
+  local modifiers = list_to_set(keys) -- SET of modifiers
   if not self.key_handlers[key] then
     -- No handlers for this key? Create a new table.
     self.key_handlers[key] = {}
   end
   table.insert(self.key_handlers[key], {
+    modifiers = modifiers,
     window = window,
     callback = callback,
     ...
@@ -299,15 +369,18 @@ function UI:addKeyHandler(key, window, callback, ...)
 end
 
 --! Unregister a key handler previously registered by `addKeyHandler`.
---!param key (string) The key of a key / window pair previously passed to
--- `addKeyHandler`.
+--!param keys (string or table) The key or list of modifiers+key of a key / window
+-- pair previously passed to `addKeyHandler`.
 --!param window (Window) The window of a key / window pair previously passed
 -- to `addKeyHandler`.
-function UI:removeKeyHandler(key, window)
-  key = key:lower()
+function UI:removeKeyHandler(keys, window)
+  keys = (type(keys) == "table") and keys or {keys}
+
+  local key = table.remove(keys, #keys):lower()
+  local modifiers = list_to_set(keys) -- SET of modifiers
   if self.key_handlers[key] then
     for index, info in ipairs(self.key_handlers[key]) do
-      if info.window == window then
+      if info.window == window and compare_tables(info.modifiers, modifiers) then
         table.remove(self.key_handlers[key], index)
       end
     end
@@ -374,15 +447,30 @@ function UI:unregisterTextBox(box)
   end
 end
 
+function UI:resetVideo()
+  local width, height = self.app.config.width, self.app.config.height
+
+  self.app.video:endFrame()
+  self.app.video = TH.surface(width, height, unpack(self.app.modes))
+  self.app.gfx:updateTarget(self.app.video)
+  self.app.video:startFrame()
+  -- Redraw cursor
+  local cursor = self.cursor
+  self.cursor = nil
+  self:setCursor(cursor)
+end
+
 function UI:changeResolution(width, height)
   local old_width, old_height = self.app.config.width, self.app.config.height
   self.app.video:endFrame()
-  local video = TH.surface(width, height, unpack(self.app.modes))
+  local video, error_message = TH.surface(width, height, unpack(self.app.modes))
   if video then
     self.app.config.width = width
     self.app.config.height = height
   else
     print("Warning: Could not change resolution to " .. width .. "x" .. height .. ". Reverting to previous resolution.")
+    print("The error was: ")
+    print(error_message)
     video = TH.surface(old_width, old_height, unpack(self.app.modes))
     return false
   end
@@ -426,6 +514,7 @@ function UI:toggleFullscreen()
   -- Toggle Fullscreen mode
   toggleMode(index)
   self.app.video:endFrame()
+  self.app.moviePlayer:deallocatePictureBuffer();
   
   local success = true
   local video = TH.surface(self.app.config.width, self.app.config.height, unpack(modes))
@@ -440,6 +529,7 @@ function UI:toggleFullscreen()
   
   self.app.video = video -- Apply changes
   self.app.gfx:updateTarget(self.app.video)
+  self.app.moviePlayer:allocatePictureBuffer();
   self.app.video:startFrame()
   -- Redraw cursor
   local cursor = self.cursor
@@ -532,54 +622,27 @@ function UI:onKeyDown(code, rawchar)
   -- the key.
   local keyHandlers = self.key_handlers[key]
   if keyHandlers then
-    -- Call only the latest (last) handler for this code, because sometimes
-    -- even cursor keys are taken over.
-    local info = keyHandlers[#keyHandlers]
-    info.callback(info.window, unpack(info))
-    return true
+    -- Iterate over key handlers and call each one whose modifier(s) are pressed
+    -- TODO: Currently, a handler is triggered regardless of additional modifiers
+    --       being pressed (example: "s" triggers when "ctrl+s" is pressed).
+    --       Decide if this is a good or bad thing.
+    local handled = false
+    for _, handler in ipairs(keyHandlers) do
+      local match = true
+      for m, _ in pairs(handler.modifiers) do
+        match = match and self.buttons_down[m]
+      end
+      if match then
+        handler.callback(handler.window, unpack(handler))
+        handled = true
+      end
+    end
+    if handled then
+      return true
+    end
   end
   
   self.buttons_down[key] = true
-  if key == "esc" then
-    -- Close the topmost window first
-    local first = self.windows[1]
-    if first.on_top and first.esc_closes then
-      first:close()
-      return true
-    end
-    for i = #self.windows, 1, -1 do
-      local window = self.windows[i]
-      if window.esc_closes then
-        window:close()
-        return true
-      end
-    end
-  elseif key == "f10" then -- Restart
-    debug.getregistry()._RESTART = true
-    TheApp.running = false
-    return true
-  elseif key == "f12" and TheApp.config.debug then -- Show console
-    self:addWindow(UILuaConsole(self))
-  elseif self.buttons_down.alt and key == "f4" then
-    if self.hospital then
-      self.app:quit()
-    else
-      self.app:exit()
-    end
-  elseif self.buttons_down.alt and key == "enter" then --Alt + Enter: Toggle Fullscreen
-    self:toggleFullscreen()
-    return true
-  elseif self.buttons_down.ctrl and key == "s" then -- Ctrl + S: Take a screenshot
-     -- Find an index for screenshot which is not already used
-    local i = 0
-    local filename
-    repeat
-      filename = (".%sscreenshot%i.bmp"):format(pathsep, i)
-      i = i + 1
-    until lfs.attributes(filename, "size") == nil
-    self.app.video:takeScreenshot(filename) -- Take screenshot
-    return true
-  end
 end
 
 --! Called when the user releases a key on the keyboard
@@ -606,6 +669,12 @@ end
 function UI:onMouseDown(code, x, y)
   local repaint = false
   local button = self.button_codes[code] or code
+  if self.app.moviePlayer.playing then
+    if button == "left" then
+      self.app.moviePlayer:stop()
+    end
+    return true
+  end
   if self.cursor_entity == nil and self.down_count == 0
   and self.cursor == self.default_cursor then
     self:setCursor(self.down_cursor)
@@ -636,7 +705,8 @@ function UI:onMouseUp(code, x, y)
   if Window.onMouseUp(self, button, x, y) then
     repaint = true
   else
-    if self.cursor_entity and self.cursor_entity.onClick then
+    if self.cursor_entity and self.cursor_entity.onClick 
+    and self.app.world.user_actions_allowed then
       self.cursor_entity:onClick(self, button)
       repaint = true
     end
@@ -718,7 +788,8 @@ function UI:addWindow(window)
     return
   end
   if window.modal_class then
-    if self.modal_windows[window.modal_class] then
+    -- NB: while instead of if in case of another window being created during the close function
+    while self.modal_windows[window.modal_class] do
       self.modal_windows[window.modal_class]:close()
     end
     self.modal_windows[window.modal_class] = window
@@ -763,6 +834,16 @@ function UI:afterLoad(old, new)
   if old < 13 then
     self.key_code_to_rawchar = {}
   end
+  if old < 63 then
+    -- modifiers have been added to key handlers
+    for key, handlers in pairs(self.key_handlers) do
+      for _, handler in ipairs(handlers) do
+        handler.modifiers = {}
+      end
+    end
+    -- some global key shortcuts were converted to use keyHandlers
+    self:setupGlobalKeyHandlers()
+  end
   
   -- disable keyboardrepeat after loading a game just in case
   -- (might be transferred from before loading, or broken savegame)
@@ -777,3 +858,62 @@ end
 -- dialog without having to worry about a GameUI being present
 function UI:tutorialStep(...)
 end
+
+function UI:makeScreenshot()
+   -- Find an index for screenshot which is not already used
+  local i = 0
+  local filename
+  repeat
+    filename = TheApp.screenshot_dir .. ("screenshot%i.bmp"):format(i)
+    i = i + 1
+  until lfs.attributes(filename, "size") == nil
+  print("Taking screenshot: " .. filename)
+  local res, err = self.app.video:takeScreenshot(filename) -- Take screenshot
+  if not res then
+    print("Screenshot failed: " .. err)
+  end
+end
+
+--! Closes one window (the topmost / active window, if possible)
+--!return true iff a window was closed
+function UI:closeWindow()
+  -- Close the topmost window first
+  local first = self.windows[1]
+  if first.on_top and first.esc_closes then
+    first:close()
+    return true
+  end
+  for i = #self.windows, 1, -1 do
+    local window = self.windows[i]
+    if window.esc_closes then
+      window:close()
+      return true
+    end
+  end
+end
+
+--! Shows the Lua console
+function UI:showLuaConsole()
+  self:addWindow(UILuaConsole(self))
+end
+
+--! Triggers reset of the application (reloads .lua files)
+function UI:resetApp()
+  debug.getregistry()._RESTART = true
+  TheApp.running = false
+end
+
+--! Triggers quitting the application
+function UI:quit()
+  self.app:exit()
+end
+
+--! Tries to stop a video, if one is currently playing
+function UI:stopMovie()
+  if self.app.moviePlayer.playing then
+    self.app.moviePlayer:stop()
+  end
+end
+
+-- Stub for compatibility with savegames r1896-1921
+function UI:stopVideo() end
\ No newline at end of file
