@@ -77,6 +77,8 @@ function World:World(app)
   self.hour = 0
 
   self.room_information_dialogs_off = app.config.debug
+  -- This is false when the game is paused.
+  self.user_actions_allowed = true
 
   -- In Free Build mode?
   if tonumber(self.map.level_number) then
@@ -91,6 +93,7 @@ function World:World(app)
   -- List of which goal criterion means what, and what number the corresponding icon has.
   self.level_criteria = local_criteria_variable
   self.room_build_callbacks = {--[[a set rather than a list]]}
+  self.room_remove_callbacks = {--[[a set rather than a list]]}
   self.room_built = {} -- List of room types that have been built
   self.hospitals = {}
   self.floating_dollars = {}
@@ -100,9 +103,13 @@ function World:World(app)
   self.original_savegame_version = app.savegame_version
   
   self:initLevel(app)
-  self.hospitals[1] = Hospital(self) -- Player's hospital
+  self.hospitals[1] = Hospital(self, app.config.player_name) -- Player's hospital
   self:initCompetitors()
   self:initRooms()
+  -- Now the hospitals can concentrate their research.
+  for i, hospital in ipairs(self.hospitals) do
+    hospital.research:setResearchConcentration()
+  end
 
   -- TODO: Add (working) AI and/or multiplayer hospitals
   -- TODO: Needs to be changed for multiplayer support
@@ -234,17 +241,17 @@ function World:initStaff()
         skill = conf.Skill / 100
       end
       
-      if conf.Nurse == 1 then
-        profile = StaffProfile("Nurse", _S.staff_class["nurse"])
-        profile:init(skill, self)
+      if conf.Nurse == 1 then 
+        profile = StaffProfile(self, "Nurse", _S.staff_class["nurse"])
+        profile:init(skill)
       elseif conf.Receptionist == 1 then
-        profile = StaffProfile("Receptionist", _S.staff_class["receptionist"])
-        profile:init(skill, self)
+        profile = StaffProfile(self, "Receptionist", _S.staff_class["receptionist"])
+        profile:init(skill)
       elseif conf.Handyman == 1 then
-        profile = StaffProfile("Handyman", _S.staff_class["handyman"])
-        profile:init(skill, self)      
+        profile = StaffProfile(self, "Handyman", _S.staff_class["handyman"])
+        profile:init(skill)      
       elseif conf.Doctor == 1 then
-        profile = StaffProfile("Doctor", _S.staff_class["doctor"])
+        profile = StaffProfile(self, "Doctor", _S.staff_class["doctor"])
         
         local shrink = 0
         local rsch = 0
@@ -258,7 +265,7 @@ function World:initStaff()
         if conf.Junior == 1 then jr = 1
         elseif conf.Consultant == 1 then cons = 1
         end
-        profile:initDoctor(shrink,surg,rsch,jr,cons,skill,self)
+        profile:initDoctor(shrink,surg,rsch,jr,cons,skill)
       else
         added_staff = false
       end
@@ -447,7 +454,7 @@ function World:calculateSpawnTiles()
     -- Choose at most 8 points for the edge
     local num = math.min(8, #xs)
     for i = 1, num do
-      local index = 1 + math.floor((i - 1) / (num - 1) * (#xs - 1) + 0.5)
+      local index = math.floor((i - 0.5) / num * #xs + 1)
       self.spawn_points[#self.spawn_points + 1] = {x = xs[index], y = ys[index], direction = edge.direction}
     end
   end
@@ -504,14 +511,19 @@ function World:spawnVIP(hospital)
 end
 
 function World:createEarthquake()
-  -- the bigger the earthquake, the longer it lasts. We add two
-  -- further days, as we use those to give a small earthquake first,
+  -- Sanity check
+  if not self.earthquake_size then
+    return false
+  end
+  
+  -- the bigger the earthquake, the longer it lasts. We add one
+  -- further day, as we use those to give a small earthquake first,
   -- before the bigger one begins
-  local stop_day = math.round(self.earthquake_size / 3) + 2
+  local stop_day = math.round(self.earthquake_size / 3) + 1
 
-  -- make sure the user has at least three days of an earthquake
-  if stop_day < 3 then
-    stop_day = 3
+  -- make sure the user has at least two days of an earthquake
+  if stop_day < 2 then
+    stop_day = 2
   end
 
   -- store the offsets so we can not shake the user to some too distant location
@@ -527,9 +539,18 @@ function World:createEarthquake()
     self.earthquake_stop_day = self.earthquake_stop_day - self:getCurrentMonthLength()
   end
 
+  -- Prepare machines for getting damage - at most as much as the severity of the earthquake +-1
+  for _, room in pairs(self.rooms) do
+    for object, value in pairs(room.objects) do
+      if object.strength then
+        object.quake_points = self.earthquake_size + math.random(-1, 1)
+      end
+    end
+  end
+  
   -- set a flag to indicate that we are now having an earthquake
   self.active_earthquake = true
-
+  return true
 end
 
 function World:tickEarthquake()
@@ -541,17 +562,31 @@ function World:tickEarthquake()
     if (self.earthquake_size > 7) then
       self.ui.adviser:say(_A.earthquake.ended:format(math.floor(self.earthquake_size)))
     end
+    -- Make sure that machines got all the damage they should get.
+    for _, room in pairs(self.rooms) do
+      for object, value in pairs(room.objects) do
+        if object.strength and object.quake_points then
+          while object.quake_points > 0 do
+            object:machineUsed(room)
+            object.quake_points = object.quake_points - 1
+          end
+        end
+      end
+    end
+  
     -- set up the next earthquake date
     self:nextEarthquake()
   else
+    -- Multiplier for how much the screen moves around during the quake.
+    local multi = 4
     if (self.day > self.earthquake_stop_day) or (self.day < math.round(self.earthquake_size / 3)) then
       -- if we are in the first two days of the earthquake, make it smaller
-      self.randomX = math.random(-(self.earthquake_size/2)*7, (self.earthquake_size/2)*7)
-      self.randomY = math.random(-(self.earthquake_size/2)*7, (self.earthquake_size/2)*7)
+      self.randomX = math.random(-(self.earthquake_size/2)*multi, (self.earthquake_size/2)*multi)
+      self.randomY = math.random(-(self.earthquake_size/2)*multi, (self.earthquake_size/2)*multi)
     else
       -- otherwise, hit the user with the full earthquake
-      self.randomX = math.random(-self.earthquake_size*7, self.earthquake_size*7)
-      self.randomY = math.random(-self.earthquake_size*7, self.earthquake_size*7)
+      self.randomX = math.random(-self.earthquake_size*multi, self.earthquake_size*multi)
+      self.randomY = math.random(-self.earthquake_size*multi, self.earthquake_size*multi)
     end
 
     -- if the game is not paused
@@ -641,8 +676,8 @@ function World:makeAvailableStaff(month)
     end
     local group = {}
     for i = 1, num do
-      group[i] = StaffProfile(info.class, _S.staff_class[info.name])
-      group[i]:randomise(self, month)
+      group[i] = StaffProfile(self, info.class, _S.staff_class[info.name])
+      group[i]:randomise(month)
     end
     self.available_staff[info.class] = group
   end
@@ -723,6 +758,19 @@ function World:unregisterRoomBuildCallback(callback)
   self.room_build_callbacks[callback] = nil
 end
 
+-- Register a function to be called whenever a room has been deactivated (crashed or edited).
+--!param callback (function) A function taking one argument: a `Room`.
+function World:registerRoomRemoveCallback(callback)
+  self.room_remove_callbacks[callback] = true
+end
+
+-- Unregister a function from being called whenever a room has been deactivated (crashed or edited).
+--!param callback (function) A function previously passed to
+-- `registerRoomRemoveCallback`.
+function World:unregisterRoomRemoveCallback(callback)
+  self.room_remove_callbacks[callback] = nil
+end
+
 function World:newRoom(x, y, w, h, room_info, ...)
   local id = #self.rooms + 1
   -- Note: Room IDs will be unique, but they may not form continuous values
@@ -737,6 +785,7 @@ function World:newRoom(x, y, w, h, room_info, ...)
   return room
 end
 
+--! Called when a room has been completely built and is ready to use
 function World:markRoomAsBuilt(room)
   room:roomFinished()
   local diag_disease = self.hospitals[1].disease_casebook["diag_" .. room.room_info.id]
@@ -748,6 +797,14 @@ function World:markRoomAsBuilt(room)
   end
 end
 
+--! Called when a room has been deactivated (crashed or edited)
+function World:notifyRoomRemoved(room)
+  self.dispatcher:dropFromQueue(room)
+  for callback in pairs(self.room_remove_callbacks) do
+    callback(room)
+  end
+end
+
 --! Clear all internal caches which are dependant upon map state / object position
 function World:clearCaches()
   self.idle_cache = {}
@@ -835,19 +892,27 @@ function World:setSpeed(speed)
   if self:isCurrentSpeed(speed) then
     return
   end
+  if speed == "Pause" then
+    -- stop screen shaking if there was an earthquake in progress
+    if self.active_earthquake then
+      self.ui.tick_scroll_amount = {x = 0, y = 0}
+    end
+    -- By default actions are not allowed when the game is paused.
+    self.user_actions_allowed = TheApp.config.allow_user_actions_while_paused
+  elseif self:getCurrentSpeed() == "Pause" then
+    self.user_actions_allowed = true
+  end
   self.prev_speed = self:getCurrentSpeed()
   local numerator, denominator = unpack(tick_rates[speed])
   self.hours_per_tick = numerator
   self.tick_rate = denominator
+  -- Set the blue filter according to whether the user can build or not.
+  TheApp.video:setBlueFilterActive(not self.user_actions_allowed)
 end
 
 -- Dedicated function to allow unpausing by pressing 'p' again
 function World:pauseOrUnpause()
   if not self:isCurrentSpeed("Pause") then
-    -- stop screen shaking if there was an earthquake in progress
-    if self.active_earthquake then
-      self.ui.tick_scroll_amount = {x = 0, y = 0}
-    end
     self:setSpeed("Pause")
   elseif self.prev_speed then
     self:setSpeed(self.prev_speed)
@@ -1228,11 +1293,10 @@ end
 
 -- Called when it is time to have another earthquake
 function World:nextEarthquake()
-
   -- check carefully that no value that we are going to use is going to be nil
   if self.map.level_config.quake_control and
   self.map.level_config.quake_control[self.current_map_earthquake] and
-  self.map.level_config.quake_control[self.current_map_earthquake] ~= 0 then
+  self.map.level_config.quake_control[self.current_map_earthquake].Severity ~= 0 then
       -- this map has rules to follow when making earthquakes, let's follow them
     local control = self.map.level_config.quake_control[self.current_map_earthquake]
     self.next_earthquake_month = math.random(control.StartMonth, control.EndMonth)
@@ -1263,8 +1327,9 @@ function World:nextEarthquake()
       self.next_earthquake_month = next_month + (self.year - 1) * 12
       self.next_earthquake_day = days
 
-      -- earthquake can be between 1 and 10 on the richter scale
-      self.earthquake_size = math.random()*10
+      -- earthquake can be between 1 and 10 (non-inclusive) on the richter scale
+      -- Make quakes at around 4 more probable.
+      self.earthquake_size = math.round(math.min(math.max(math.n_random(4,2), 1), 9))
     end
   end
 end
@@ -1378,11 +1443,14 @@ end
 --!param limit (number) [optional] The number the player went over/under which caused him to lose.
 function World:loseGame(player_no, reason, limit)
   if player_no == 1 then -- TODO: Multiplayer
+    self.ui.app.moviePlayer:playLoseMovie()
     local message = {_S.information.level_lost[1]}
     if reason then
       message[2] = _S.information.level_lost[2]
-      message[3] = _S.information.level_lost[reason]:format(limit)
-    end
+      message[3] = _S.information.level_lost[reason]:format(limit)    
+    else   
+      message[2] = _S.information.level_lost["cheat"]     
+     end
     self.ui.app:loadMainMenu(message)
   end
 end
@@ -1757,17 +1825,12 @@ end
 function World:removeObjectFromTile(object, x, y)
   local index = (y - 1) * self.map.width + x
   local objects = self.objects[index]
+  local thob = object.object_type.thob
   if objects then
     for k, v in ipairs(objects) do
       if v == object then
         table_remove(objects, k)
-        if k == 1 then
-          if objects[1] then
-            self.map.th:setCellFlags(x, y, {thob = objects[1].object_type.thob})
-          else
-            self.map.th:setCellFlags(x, y, {thob = 0})
-          end
-        end
+        self.map.th:removeObjectType(x, y, thob)
         local count_cat = object.object_type.count_category
         if count_cat then
           self.object_counts[count_cat] = self.object_counts[count_cat] - 1
@@ -1788,15 +1851,7 @@ function World:addObjectToTile(object, x, y)
   local index = (y - 1) * self.map.width + x
   local objects = self.objects[index]
   if objects then
-    if #objects >= 1 then
-      -- Until it is clear how multiple objects will work, this warning should
-      -- be in place. In most cases, having multiple objects on a tile should
-      -- be impossible, but there are some edge cases like having two radiators
-      -- or bins on a tile which need thinking about.
-      print("Warning: Multiple objects on tile " .. x .. "," .. y .. " - only one will be encoded")
-    else
-      self.map.th:setCellFlags(x, y, {thob = object.object_type.thob})
-    end
+    self.map.th:setCellFlags(x, y, {thob = object.object_type.thob})
     objects[#objects + 1] = object
   else
     objects = {object}
@@ -1837,6 +1892,33 @@ function World:getObject(x, y, id)
   return -- nil
 end
 
+function World:getObjectsById(id)
+  if not id then
+      return self.objects
+  end
+  
+  local ret = {}
+  if type(id) == "table" then
+    for position, obj_list in pairs(self.objects) do
+      for _, obj in ipairs(obj_list) do
+        if id[obj.object_type.id] then
+          table.insert(ret, obj)
+        end
+      end
+    end
+  else
+    for position, obj_list in pairs(self.objects) do
+      for _, obj in ipairs(obj_list) do
+        if obj.object_type.id == id then
+          table.insert(ret, obj)
+        end
+      end
+    end
+  end
+  
+  return ret
+end
+
 function World:getRoom(x, y)
   return self.rooms[self.map:getRoomId(x, y)]
 end
@@ -1897,6 +1979,14 @@ function World:dumpGameLog()
   end
 end
 
+-- Because the save file only saves one thob per tile if they are more that information 
+-- will be lost. To solve this after a load we need to set again all the thobs on each tile.
+function World:resetAnimations()
+  for _, entity in ipairs(self.entities) do
+    entity:resetAnimation()
+  end
+end
+
 --! Let the world react to and old save game. First it gets the chance to
 -- do things for itself, and then it calls corresponding functions for
 -- the hospitals, entities and rooms in that order.
@@ -1908,7 +1998,7 @@ function World:afterLoad(old, new)
     self.original_savegame_version = old
   end
   -- If the original save game version is considerably lower than the current, warn the player.
-  if new - 10 > self.original_savegame_version then
+  if new - 20 > self.original_savegame_version then
     self.ui:addWindow(UIInformation(self.ui, {_S.information.very_old_save}))
   end
   -- insert global compatibility code here
@@ -2092,7 +2182,49 @@ function World:afterLoad(old, new)
     -- Now set up the next earthquake.
     self:nextEarthquake()
   end
-
+  if old < 57 then
+    self.user_actions_allowed = true
+  end
+  if old < 61 then
+    -- room remove callbacks added
+    self.room_remove_callbacks = {}
+  end
+  if old < 64 then
+    -- added reference to world for staff profiles
+    for _, group in pairs(self.available_staff) do
+      for _, profile in ipairs(group) do
+        profile.world = self
+      end
+    end
+  end
+  if old < 66 then
+    -- Unreserve objects which are not actually reserved for real in the staff room.
+    -- This is a special case where reserved_for could be set just as a staff member was leaving
+    for _, room in pairs(self.rooms) do
+      if room.room_info.id == "staff_room" then
+        -- Find all objects in the room
+        local fx, fy = room:getEntranceXY(true)
+        for obj, _ in pairs(self:findAllObjectsNear(fx, fy)) do
+          if obj.reserved_for then
+            local found = false
+            for _, action in ipairs(obj.reserved_for.action_queue) do
+              if action.name == "use_object" then
+                if action.object == obj then
+                  found = true
+                  break
+                end
+              end
+            end
+            if not found then
+              self:gameLog("Unreserved an object: " .. obj.object_type.id .. " at " .. obj.tile_x .. ":" .. obj.tile_y)
+              obj.reserved_for = nil
+            end
+          end
+        end
+      end
+    end
+  end
+  
   -- Now let things inside the world react.
   for _, cat in pairs({self.hospitals, self.entities, self.rooms}) do
     for _, obj in pairs(cat) do
@@ -2102,3 +2234,17 @@ function World:afterLoad(old, new)
   
   self.savegame_version = new
 end
+
+--[[ There is a problem with room editing in that it resets all the partial passable flags
+(travelNorth, travelSouth etc.) in the corridor, a workaround is calling this function
+after the room was edited so that all edge only objects, that set partial passable flags set
+those flags again]] 
+function World:resetSideObjects()
+  for _, objects in pairs(self.objects) do
+    for _, obj in ipairs(objects) do
+      if obj.object_type.class == "SideObject" then
+        obj:setTile(obj.tile_x, obj.tile_y)
+      end
+    end
+  end
+end
